(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    182825,       5926]*)
(*NotebookOutlinePosition[    183531,       5950]*)
(*  CellTagsIndexPosition[    183487,       5946]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Concepts and Methods of 2D Infrared Spectroscopy
Peter Hamm and Martin T. Zanni\
\>", "Section"],

Cell[CellGroupData[{

Cell["This progam was used to produce Figs. 4.14 and 10.8.", "Subsubtitle"],

Cell["\<\
Number of single excited states, and their frequencies and transition \
dipoles, taken from the Gaussian output. An offset-frequency is subtracted \
(and added back in after the Fouriertransform) to save computation time. The \
two transition dipoles are in the x- and y-axis, respectively.\
\>", "Text"],

Cell[BoxData[{
    \(\(n = 2;\)\), "\[IndentingNewLine]", 
    \(\(w = {1889.184, \ 1947.621};\)\), "\[IndentingNewLine]", 
    \(\(mu = {Sqrt[ .908] {1. , 0, 0}, 
          Sqrt[ .671] {0, 1. , 0}};\)\), "\[IndentingNewLine]", 
    \(\(woff = 1915;\)\), "\[IndentingNewLine]", 
    \(\ \(w -= woff;\)\)}], "Input"],

Cell["\<\
Number of double excited states, and their frequencies and transition \
dipoles, taken from the Gaussian output. We use the harmonic approximation \
for the transition dipoles.\
\>", "Text"],

Cell[BoxData[{
    \(\(n2 = 3;\)\), "\[IndentingNewLine]", 
    \(\(w2 = {3767.517, \ \ 3883.911, \ \ 3813.698};\)\), \
"\[IndentingNewLine]", 
    \(\(w2 -= 2  woff;\)\), "\[IndentingNewLine]", 
    \(\(mu2 = {{Sqrt[2] mu[\([1]\)], {0, 0, 0}, mu[\([2]\)]}, {{0, 0, 0}, 
            Sqrt[2] mu[\([2]\)], mu[\([1]\)]}};\)\)}], "Input"],

Cell["Parameters and constants", "Text"],

Cell[BoxData[{
    \(\(nt = 128;\)\ \), "\[IndentingNewLine]", 
    \(\(dt = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(T2 = 2. ;\)\), "\[IndentingNewLine]", 
    \(\(c =  .188;\)\), "\[IndentingNewLine]", 
    \(\(t2 = 0;\)\)}], "Input"],

Cell["\<\
Calculate response functions for rephasing and non-rephasing diagrams (Eqs. \
10.11, 10.12, and 10.13). The first time-point needs to be halved \
(Sect.9.5.3).\
\>", "Text"],

Cell[BoxData[{
    \(\(Rr = 
        Table[0. , {it1, 1, nt}, {it3, 1, nt}];\)\), "\[IndentingNewLine]", 
    \(\(Rnr = 
        Table[0. , {it1, 1, nt}, {it3, 1, nt}];\)\), "\[IndentingNewLine]", 
    \(For[j = 1, 
      j \[LessEqual] n, \(j++\), \[IndentingNewLine]For[i = 1, 
        i \[LessEqual] n, \(i++\), \[IndentingNewLine]mui = 
          Sqrt[mu[\([i]\)] . mu[\([i]\)]]; \[IndentingNewLine]muj = 
          Sqrt[mu[\([j]\)] . 
              mu[\([j]\)]]; \[IndentingNewLine]cos1 = \(mu[\([i]\)] . 
                mu[\([j]\)]/mui\)/
            muj; \[IndentingNewLine]angle = \((1 + 2\ cos1^2)\)/
            15; \[IndentingNewLine]dipole = 
          mui^2*muj^2; \[IndentingNewLine]\[IndentingNewLine] (*Rephasing\ \
diagram\ R1*) \[IndentingNewLine]Rr -= 
          dipole\ angle\ Table[
              Exp[\(+I\)\ w[\([j]\)] c\ \ \((it1 - 1)\) dt - 
                  I\ w[\([i]\)] c\ \((it3 - 1)\) dt + 
                  I \((w[\([j]\)] - w[\([i]\)])\) 
                    c\ t2 - \((it1 + it3 - 2)\)\ dt\ /T2]\ , {it1, 1, 
                nt}, {it3, 1, 
                nt}]; \[IndentingNewLine] (*Rephasing\ diagram\ R2\
*) \[IndentingNewLine]Rr -= 
          dipole\ angle\ Table[
              Exp[\(+I\)\ w[\([j]\)] c\ \ \((it1 - 1)\) dt - 
                  I\ w[\([i]\)] c\ \((it3 - 1)\) 
                    dt - \((it1 + it3 - 2)\)\ dt\ /T2]\ , {it1, 1, nt}, {it3, 
                1, nt}]; \[IndentingNewLine]\[IndentingNewLine]For[k = 1, 
          k \[LessEqual] n2, \(k++\), \[IndentingNewLine]mujk = 
            Sqrt[mu2[\([j, k]\)] . 
                mu2[\([j, k]\)]]; \[IndentingNewLine]muik = 
            Sqrt[mu2[\([i, k]\)] . 
                mu2[\([i, k]\)]]; \[IndentingNewLine]dipole = 
            mui*muj*muik*mujk; \[IndentingNewLine]cos2 = 
            If[muik\  \[NotEqual] \ 0\  && \ 
                mujk\  \[NotEqual] \ 0, \ \(mu2[\([i, k]\)] . mu2[\([j, k]\)]/
                  muik\)/mujk, 0]; \[IndentingNewLine]cos3 = 
            If[muik\  \[NotEqual] \ 
                0\ , \(mu[\([i]\)] . mu2[\([i, k]\)]/mui\)/muik, 
              0]; \[IndentingNewLine]cos4 = 
            If[mujk\  \[NotEqual] \ 0, \(mu[\([j]\)] . mu2[\([j, k]\)]/muj\)/
                mujk, 0]; \[IndentingNewLine]cos5 = 
            If[mujk\  \[NotEqual] \ 0, \(mu[\([i]\)] . mu2[\([j, k]\)]/mui\)/
                mujk, 0]; \[IndentingNewLine]cos6 = 
            If[muik\  \[NotEqual] \ 
                0\ , \(mu[\([j]\)] . mu2[\([i, k]\)]/muj\)/muik, 
              0]; \[IndentingNewLine]angle = \((cos1\ cos2 + cos3\ cos4 + 
                  cos5\ cos6)\)/
              15; \[IndentingNewLine]\[IndentingNewLine] (*Rephasing\ diagram\
\ R3*) \[IndentingNewLine]Rr += 
            angle\ dipole\ Table[
                Exp[\(+I\)\ w[\([j]\)] c\ \ \((it1 - 1)\) dt - 
                    I\ \((w2[\([k]\)] - w[\([j]\)])\) c\ \((it3 - 1)\) dt + 
                    I \((w[\([j]\)] - w[\([i]\)])\) 
                      c\ t2 - \((it1 + it3 - 2)\)\ dt\ /T2]\ , {it1, 1, 
                  nt}, {it3, 1, 
                  nt}];\[IndentingNewLine]\[IndentingNewLine]]\
\[IndentingNewLine]]\[IndentingNewLine]]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(For[j = 1, 
      j \[LessEqual] n, \(j++\), \[IndentingNewLine]For[i = 1, 
        i \[LessEqual] n, \(i++\), \[IndentingNewLine]mui = 
          Sqrt[mu[\([i]\)] . mu[\([i]\)]]; \[IndentingNewLine]muj = 
          Sqrt[mu[\([j]\)] . 
              mu[\([j]\)]]; \[IndentingNewLine]cos1 = \(mu[\([i]\)] . 
                mu[\([j]\)]/mui\)/
            muj; \[IndentingNewLine]angle = \((1 + 2\ cos1^2)\)/
            15; \[IndentingNewLine]dipole\  = \ 
          mui^2*muj^2; \[IndentingNewLine]\[IndentingNewLine] (*Non - 
            rephasing\ diagram\ R4*) \[IndentingNewLine]Rnr -= 
          dipole\ angle\ Table[
              Exp[\(-I\)\ w[\([j]\)] c\ \ \((it1 - 1)\) dt - 
                  I\ w[\([j]\)] c\ \((it3 - 1)\) dt - 
                  I \((w[\([j]\)] - w[\([i]\)])\) 
                    c\ t2 - \((it1 + it3 - 2)\)\ dt\ /T2]\ , {it1, 1, 
                nt}, {it3, 1, nt}]; \[IndentingNewLine] (*Non - 
            rephasing\ Diagram\ R5*) \[IndentingNewLine]Rnr -= 
          dipole\ angle\ Table[
              Exp[\(-I\)\ w[\([j]\)] c\ \ \((it1 - 1)\) dt - 
                  I\ w[\([i]\)] c\ \((it3 - 1)\) 
                    dt - \((it1 + it3 - 2)\)\ dt\ /T2]\ , {it1, 1, nt}, {it3, 
                1, nt}]; \[IndentingNewLine]\[IndentingNewLine]For[k = 1, 
          k \[LessEqual] n2, \(k++\), \[IndentingNewLine]mujk = 
            Sqrt[mu2[\([j, k]\)] . 
                mu2[\([j, k]\)]]; \[IndentingNewLine]muik = 
            Sqrt[mu2[\([i, k]\)] . 
                mu2[\([i, k]\)]]; \[IndentingNewLine]dipole = 
            mui*muj*muik*mujk; \[IndentingNewLine]cos2 = 
            If[muik\  \[NotEqual] \ 0\  && \ 
                mujk\  \[NotEqual] \ 0, \ \(mu2[\([i, k]\)] . mu2[\([j, k]\)]/
                  muik\)/mujk, 0]; \[IndentingNewLine]cos3 = 
            If[muik\  \[NotEqual] \ 
                0\ , \(mu[\([i]\)] . mu2[\([i, k]\)]/mui\)/muik, 
              0]; \[IndentingNewLine]cos4 = 
            If[mujk\  \[NotEqual] \ 0, \(mu[\([j]\)] . mu2[\([j, k]\)]/muj\)/
                mujk, 0]; \[IndentingNewLine]cos5 = 
            If[mujk\  \[NotEqual] \ 0, \(mu[\([i]\)] . mu2[\([j, k]\)]/mui\)/
                mujk, 0]; \[IndentingNewLine]cos6 = 
            If[muik\  \[NotEqual] \ 
                0\ , \(mu[\([j]\)] . mu2[\([i, k]\)]/muj\)/muik, 
              0]; \[IndentingNewLine]angle = \((cos1\ cos2 + cos3\ cos4 + 
                  cos5\ cos6)\)/
              15; \[IndentingNewLine]\[IndentingNewLine] (*Non - 
              rephasing\ diagram\ R6*) \[IndentingNewLine]Rnr += 
            angle\ dipole\ Table[
                Exp[\(-I\)\ w[\([j]\)] c\ \ \((it1 - 1)\) dt - 
                    I\ \((w2[\([k]\)] - w[\([i]\)])\) c\ \((it3 - 1)\) dt - 
                    I \((w[\([j]\)] - w[\([i]\)])\) 
                      c\ t2 - \((it1 + it3 - 2)\)\ dt\ /T2]\ , {it1, 1, 
                  nt}, {it3, 1, 
                  nt}];\[IndentingNewLine]]\[IndentingNewLine]]\
\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(\(For[i = 1, i \[LessEqual] nt, \(i++\), Rnr[\([i, 1]\)] /= 2; 
        Rr[\([i, 1]\)] /= 2];\)\), "\n", 
    \(\(For[i = 2, i \[LessEqual] nt, \(i++\), Rnr[\([1, i]\)] /= 2; 
        Rr[\([1, i]\)] /= 2];\)\)}], "Input"],

Cell["Plot time-domain data", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ListContourPlot[Re[Rr], \ PlotRange \[Rule] All, Contours \[Rule] 10, 
      ContourShading \[Rule] False, FrameTicks \[Rule] None, 
      FrameLabel \[Rule] {t3, t1}]\), "\[IndentingNewLine]", 
    \(ListContourPlot[Re[Rnr], \ PlotRange \[Rule] All, Contours \[Rule] 10, 
      ContourShading \[Rule] False, FrameTicks \[Rule] None, 
      FrameLabel \[Rule] {t3, t1}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0116596 0.00757117 0.0116596 0.00757117 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -12.5625 -8 ]
[-0.01875 .5 0 8 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t3) show
1.000 setlinewidth
grestore
0 0 m
0 1 L
s
gsave
-0.01875 .5 -75.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t1) show
1.000 setlinewidth
grestore
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.04952 .03178 m
.05709 .03339 L
.05795 .03437 L
.06341 .04194 L
.05709 .04218 L
.05672 .04194 L
.04952 .03524 L
.0492 .03437 L
.04952 .03178 L
s
.03437 .04816 m
.04027 .04952 L
.04194 .0515 L
.0434 .05709 L
.04952 .06355 L
.05114 .06466 L
.05709 .07114 L
.05796 .07223 L
.05709 .07611 L
.05139 .07223 L
.04952 .07042 L
.04746 .06466 L
.04194 .05934 L
.03437 .0572 L
.03423 .05709 L
.03282 .04952 L
.03437 .04816 L
s
.04952 .02914 m
.05709 .03221 L
.05899 .03437 L
.06466 .04125 L
.0653 .04194 L
.0715 .04952 L
.07223 .05039 L
.07553 .05709 L
.07223 .05801 L
.07123 .05709 L
.06466 .05117 L
.06321 .04952 L
.05709 .04346 L
.05493 .04194 L
.04952 .03704 L
.04835 .03437 L
.04952 .02914 L
s
.0798 .02205 m
.08244 .0268 L
.08737 .03247 L
.08966 .03437 L
.08737 .03758 L
.08495 .03437 L
.0798 .0297 L
.07674 .0268 L
.0798 .02205 L
s
.03437 .08373 m
.0398 .08737 L
.03437 .09095 L
.0323 .08737 L
.03437 .08373 L
s
.08737 .07008 m
.08778 .07223 L
.08737 .07244 L
.08712 .07223 L
.08737 .07008 L
s
.03437 .04679 m
.04194 .04923 L
.04206 .04952 L
.04485 .05709 L
.04952 .06195 L
.05305 .06466 L
.05709 .069 L
.05987 .07223 L
.06466 .07857 L
.06571 .0798 L
.06466 .08493 L
.05808 .0798 L
.05709 .0791 L
.04952 .07269 L
.04913 .07223 L
.04533 .06466 L
.04194 .0613 L
.03437 .05864 L
.03252 .05709 L
.03127 .04952 L
.03437 .04679 L
s
.04952 .02717 m
.05709 .03113 L
.05994 .03437 L
.06466 .04 L
.06649 .04194 L
.07223 .04852 L
.07366 .04952 L
.07814 .05709 L
.07223 .0598 L
.06947 .05709 L
.06466 .05257 L
.06199 .04952 L
.05709 .04461 L
.05341 .04194 L
.04952 .03849 L
.04756 .03437 L
.04952 .02717 L
s
.0798 .02069 m
.08436 .0268 L
.08737 .03018 L
.09212 .03437 L
.08737 .04019 L
.08262 .03437 L
.0798 .03167 L
.07487 .0268 L
.0798 .02069 L
s
.04298 .01923 m
.04194 .02276 L
.037 .01923 L
s
.03437 .0813 m
.04194 .08599 L
.04226 .08737 L
.04742 .09494 L
.04952 .09699 L
.05342 .10251 L
.05709 .10854 L
.05821 .11008 L
.05709 .11247 L
.05543 .11008 L
.04952 .10621 L
.04578 .10251 L
.04194 .09855 L
.03679 .09494 L
.03437 .09357 L
.03023 .08737 L
.03437 .0813 L
s
.03437 .04555 m
.04194 .04725 L
.04307 .04952 L
.04616 .05709 L
.04952 .06056 L
.0546 .06466 L
.05709 .0673 L
.0615 .07223 L
.06466 .07614 L
.06802 .0798 L
.07223 .08442 L
.07506 .08737 L
.07223 .09488 L
.06466 .08839 L
.06376 .08737 L
.05709 .08122 L
.05575 .0798 L
.04952 .07429 L
.04777 .07223 L
.0436 .06466 L
.04194 .06301 L
.03437 .05993 L
.03091 .05709 L
.02982 .04952 L
.03437 .04555 L
s
.1328 .0265 m
.1329 .0268 L
.14037 .03394 L
.14078 .03437 L
.14037 .03683 L
.13696 .03437 L
.1328 .02895 L
.13225 .0268 L
.1328 .0265 L
s
.07802 .01923 m
.0798 .01968 L
.08607 .0268 L
.08737 .02824 L
.0942 .03437 L
.09494 .03675 L
.09569 .04194 L
.09494 .04296 L
.08737 .04218 L
.0871 .04194 L
.08083 .03437 L
.0798 .03335 L
.07334 .0268 L
.07223 .02548 L
.06852 .01923 L
s
.04494 .01923 m
.04952 .02536 L
.05179 .0268 L
.05709 .03009 L
.06086 .03437 L
.06466 .03885 L
.0676 .04194 L
.07223 .04716 L
.0743 .04952 L
.0798 .05661 L
.08011 .05709 L
.08669 .06466 L
.08737 .06508 L
.09241 .07223 L
.08737 .07639 L
.08329 .07223 L
.0798 .06718 L
.07763 .06466 L
.07223 .06137 L
.068 .05709 L
.06466 .05385 L
.06087 .04952 L
.05709 .04569 L
.05199 .04194 L
.04952 .03979 L
.0468 .03437 L
.04564 .0268 L
.04194 .02482 L
.03437 .0234 L
.03355 .01923 L
s
.04952 .2207 m
.05294 .22365 L
.04952 .22559 L
.04835 .22365 L
.04952 .2207 L
s
.03437 .2046 m
.04194 .20831 L
.04204 .20851 L
.04194 .21494 L
.03437 .21249 L
.03229 .20851 L
.03437 .2046 L
s
.08737 .18931 m
.08899 .19337 L
.08737 .19378 L
.08698 .19337 L
.08737 .18931 L
s
.03437 .17061 m
.04194 .16767 L
.04366 .17065 L
.04356 .17823 L
.04952 .18413 L
.05343 .1858 L
.05709 .18874 L
.06072 .19337 L
.06466 .19807 L
.06716 .20094 L
.07223 .20707 L
.07356 .20851 L
.07223 .21286 L
.06695 .20851 L
.06466 .20665 L
.05913 .20094 L
.05709 .19934 L
.04952 .19341 L
.04948 .19337 L
.04784 .1858 L
.04194 .17956 L
.03528 .17823 L
.03437 .17706 L
.03435 .17065 L
.03437 .17061 L
s
.05709 .14902 m
.06074 .15551 L
.06466 .16039 L
.06701 .16308 L
.07223 .17001 L
.07276 .17065 L
.07921 .17823 L
.07223 .17921 L
.07136 .17823 L
.06466 .17158 L
.06392 .17065 L
.05841 .16308 L
.05709 .16214 L
.0516 .15551 L
.05709 .14902 L
s
.0798 .14113 m
.08513 .14794 L
.08737 .15281 L
.0893 .15551 L
.08737 .15624 L
.08682 .15551 L
.0798 .15077 L
.07774 .14794 L
.0798 .14113 L
s
.0268 .10766 m
.02751 .11008 L
.03437 .11541 L
.03699 .11766 L
.04194 .12276 L
.0437 .12523 L
.04952 .13148 L
.05017 .1328 L
.04952 .13844 L
.04194 .14005 L
.03714 .1328 L
.03437 .12981 L
.02997 .12523 L
.02701 .11766 L
.0268 .1171 L
.02031 .11008 L
.0268 .10766 L
s
.0268 .06725 m
.02775 .07223 L
.03437 .07939 L
.03531 .0798 L
.04194 .08164 L
.04399 .08737 L
.04952 .09406 L
.05049 .09494 L
.05675 .10251 L
.05709 .10294 L
.06336 .11008 L
.06466 .11211 L
.06988 .11766 L
.07223 .12015 L
.07459 .12523 L
.07223 .1325 L
.06466 .12737 L
.06317 .12523 L
.05709 .11984 L
.05561 .11766 L
.0499 .11008 L
.04952 .10977 L
.04259 .10251 L
.04194 .10181 L
.03437 .09596 L
.03238 .09494 L
.0282 .08737 L
.0268 .08203 L
.02427 .0798 L
.01955 .07223 L
.0268 .06725 L
s
.11766 .04775 m
.12523 .04834 L
.12635 .04952 L
.1328 .05692 L
.13301 .05709 L
.13804 .06466 L
.1328 .06992 L
.12745 .06466 L
.12523 .06207 L
.11932 .05709 L
.11766 .05444 L
.1167 .04952 L
.11766 .04775 L
s
.0268 .02737 m
.02829 .03437 L
.02854 .04194 L
.03437 .04435 L
.04194 .0462 L
.04402 .04952 L
.04741 .05709 L
.04952 .05926 L
.05603 .06466 L
.05709 .06576 L
.06305 .07223 L
.06466 .07415 L
.07014 .0798 L
.07223 .0819 L
.07777 .08737 L
.0798 .09358 L
.08051 .09494 L
.08737 .10021 L
.09115 .10251 L
.09219 .11008 L
.08737 .1148 L
.08076 .11008 L
.0798 .10763 L
.07857 .10251 L
.07223 .0983 L
.06865 .09494 L
.06466 .09105 L
.06152 .08737 L
.05709 .08313 L
.05403 .0798 L
.04952 .07581 L
.04651 .07223 L
.04195 .06466 L
.04194 .06465 L
.03437 .06117 L
.02928 .05709 L
.02833 .04952 L
.0268 .04369 L
.01987 .04194 L
.01947 .03437 L
.0268 .02737 L
s
.16481 .01923 m
.16953 .0268 L
.17065 .02809 L
.17823 .03305 L
.17948 .03437 L
.18056 .04194 L
.17823 .0446 L
.17065 .04276 L
.16998 .04194 L
.16638 .03437 L
.16308 .03102 L
.15794 .0268 L
.15551 .02411 L
.15112 .01923 L
s
.13068 .01923 m
.1328 .02041 L
.13827 .0268 L
.14037 .02903 L
.14547 .03437 L
.14794 .03714 L
.15213 .04194 L
.15551 .04634 L
.15984 .04952 L
.16308 .05649 L
.1632 .05709 L
.16308 .05868 L
.15551 .0605 L
.15289 .05709 L
.14794 .05228 L
.1453 .04952 L
.14037 .0442 L
.13842 .04194 L
.1328 .03645 L
.13126 .03437 L
.12523 .02776 L
.12228 .0268 L
.11766 .02417 L
.11631 .01923 L
s
.10676 .01923 m
.10251 .022 L
.10071 .01923 L
s
.08109 .01923 m
.08737 .02633 L
.08801 .0268 L
.09494 .03229 L
.09667 .03437 L
.10007 .04194 L
.10251 .04511 L
.10666 .04952 L
.10743 .05709 L
.10251 .05895 L
.10075 .05709 L
.09675 .04952 L
.09494 .04782 L
.08737 .04387 L
.08535 .04194 L
.0798 .03499 L
.07932 .03437 L
.07223 .02709 L
.07202 .0268 L
.06578 .01923 L
s
.04665 .01923 m
.04952 .0235 L
.05376 .0268 L
.05709 .02905 L
.06176 .03437 L
.06466 .03775 L
.06868 .04194 L
.07223 .04588 L
.07443 .04952 L
.0798 .05418 L
.08185 .05709 L
.08737 .0628 L
.09155 .06466 L
.09494 .06971 L
.09609 .07223 L
.09775 .0798 L
.10251 .08493 L
.10423 .08737 L
.10251 .09184 L
.09935 .08737 L
.09494 .08348 L
.08925 .0798 L
.08737 .07936 L
.08079 .07223 L
.0798 .07069 L
.07491 .06466 L
.07223 .06286 L
.06666 .05709 L
.06466 .05511 L
.05981 .04952 L
.05709 .04675 L
.05059 .04194 L
.04952 .04103 L
.04606 .03437 L
.04275 .0268 L
.04194 .0264 L
.03437 .02557 L
.03048 .01923 L
s
.03437 .09853 m
.03959 .10251 L
.04194 .10564 L
.04576 .11008 L
.04952 .1145 L
.05142 .11766 L
.04952 .12282 L
.04194 .11826 L
.04139 .11766 L
.03437 .11153 L
.03257 .11008 L
.02925 .10251 L
.03437 .09853 L
s
.0268 .05035 m
.0274 .05709 L
.03437 .06241 L
.03986 .06466 L
.04194 .06641 L
.04527 .07223 L
.04952 .07733 L
.05232 .0798 L
.05709 .08509 L
.05941 .08737 L
.06466 .0938 L
.06574 .09494 L
.07223 .10185 L
.07313 .10251 L
.07514 .11008 L
.07223 .11294 L
.06841 .11008 L
.06466 .10682 L
.0605 .10251 L
.05709 .09982 L
.0529 .09494 L
.04952 .09195 L
.04567 .08737 L
.04194 .08082 L
.03838 .0798 L
.03437 .07782 L
.02941 .07223 L
.02869 .06466 L
.0268 .05992 L
.02018 .05709 L
.0268 .05035 L
s
.12523 .0317 m
.12772 .03437 L
.1328 .04141 L
.13335 .04194 L
.13848 .04952 L
.1328 .05053 L
.13191 .04952 L
.12523 .04263 L
.12384 .04194 L
.11863 .03437 L
.12523 .0317 L
s
.03437 .02726 m
.04194 .02782 L
.04533 .03437 L
.04904 .04194 L
.04952 .04227 L
.05709 .04782 L
.05875 .04952 L
.06466 .05638 L
.06536 .05709 L
.07223 .06438 L
.07261 .06466 L
.07872 .07223 L
.0798 .07514 L
.08289 .0798 L
.08737 .08286 L
.09204 .08737 L
.08737 .09494 L
.08084 .08737 L
.0798 .08549 L
.07258 .0798 L
.07223 .07963 L
.06466 .07228 L
.06461 .07223 L
.05747 .06466 L
.05709 .06432 L
.04952 .05798 L
.04864 .05709 L
.04496 .04952 L
.04194 .04552 L
.03437 .04317 L
.0316 .04194 L
.02957 .03437 L
.03437 .02726 L
s
.14482 .01923 m
.14794 .02018 L
.15359 .0268 L
.15551 .02942 L
.16103 .03437 L
.15551 .04026 L
.1499 .03437 L
.14794 .03285 L
.14216 .0268 L
.14037 .02445 L
.13666 .01923 L
s
.09583 .01923 m
.1006 .0268 L
.10251 .02925 L
.10558 .03437 L
.10251 .03875 L
.10004 .03437 L
.09494 .02919 L
.09122 .0268 L
.08737 .0242 L
.08377 .01923 L
s
.06346 .01923 m
.06466 .01963 L
.07093 .0268 L
.07223 .02852 L
.07801 .03437 L
.0798 .03671 L
.08377 .04194 L
.08737 .04555 L
.09328 .04952 L
.09494 .05337 L
.09623 .05709 L
.09494 .06161 L
.08737 .0608 L
.08362 .05709 L
.0798 .05198 L
.07561 .04952 L
.07223 .04462 L
.06978 .04194 L
.06466 .03667 L
.06268 .03437 L
.05709 .02798 L
.05546 .0268 L
.04952 .02135 L
.04832 .01923 L
s
.03437 .10177 m
.03561 .10251 L
.03437 .10659 L
.03329 .10251 L
.03437 .10177 L
s
.03437 .06371 m
.03732 .06466 L
.04194 .06834 L
.044 .07223 L
.04952 .07898 L
.05047 .0798 L
.05709 .08732 L
.05714 .08737 L
.06204 .09494 L
.05709 .09662 L
.0556 .09494 L
.04952 .08979 L
.04747 .08737 L
.04194 .0801 L
.04143 .0798 L
.03437 .07624 L
.03094 .07223 L
.03155 .06466 L
.03437 .06371 L
s
.03437 .02882 m
.04194 .02919 L
.04459 .03437 L
.04698 .04194 L
.04952 .04356 L
.05709 .04893 L
.05766 .04952 L
.06398 .05709 L
.06466 .05786 L
.0707 .06466 L
.07223 .06634 L
.07672 .07223 L
.07223 .07744 L
.06657 .07223 L
.06466 .0705 L
.05908 .06466 L
.05709 .06294 L
.04996 .05709 L
.04952 .05665 L
.0459 .04952 L
.04194 .04467 L
.0344 .04194 L
.03437 .04193 L
.03076 .03437 L
.03437 .02882 L
s
.14794 .02403 m
.14852 .0268 L
.14794 .02749 L
.1473 .0268 L
.14794 .02403 L
s
.08999 .01923 m
.08737 .02076 L
.0871 .01923 L
s
.06119 .01923 m
.06466 .02043 L
.06984 .0268 L
.07223 .02989 L
.0767 .03437 L
.0798 .03859 L
.08219 .04194 L
.08737 .04734 L
.09065 .04952 L
.09259 .05709 L
.08737 .05872 L
.08561 .05709 L
.0798 .04969 L
.07938 .04952 L
.07223 .04334 L
.07093 .04194 L
.06466 .03557 L
.06362 .03437 L
.05709 .02682 L
.05706 .0268 L
.05031 .01923 L
s
.03437 .06536 m
.04194 .0707 L
.04263 .07223 L
.04194 .07705 L
.03437 .07453 L
.0325 .07223 L
.03437 .06536 L
s
.03437 .0304 m
.04194 .03058 L
.04382 .03437 L
.0442 .04194 L
.04952 .04496 L
.0564 .04952 L
.05709 .05027 L
.06244 .05709 L
.06466 .05977 L
.06873 .06466 L
.07223 .06896 L
.07438 .07223 L
.07223 .07482 L
.06909 .07223 L
.06466 .06855 L
.06089 .06466 L
.05709 .06149 L
.05148 .05709 L
.04952 .05515 L
.04689 .04952 L
.04194 .04308 L
.03794 .04194 L
.03437 .04033 L
.03194 .03437 L
.03437 .0304 L
s
.05838 .01923 m
.06466 .02137 L
.06872 .0268 L
.07223 .03131 L
.07532 .03437 L
.0798 .0409 L
.08045 .04194 L
.08737 .0495 L
.0874 .04952 L
.08737 .05579 L
.0836 .04952 L
.0798 .04639 L
.07223 .04196 L
.07221 .04194 L
.06466 .0344 L
.06463 .03437 L
.05849 .0268 L
.05709 .02547 L
.05363 .01923 L
s
.03437 .06852 m
.04037 .07223 L
.03437 .07236 L
.03428 .07223 L
.03437 .06852 L
s
.04952 .04656 m
.0548 .04952 L
.05709 .05204 L
.06066 .05709 L
.06466 .06256 L
.06611 .06466 L
.06466 .06597 L
.06335 .06466 L
.05709 .05986 L
.05327 .05709 L
.04952 .0534 L
.04796 .04952 L
.04952 .04656 L
s
.03437 .03217 m
.04194 .0321 L
.04301 .03437 L
.04194 .04088 L
.03437 .03833 L
.03316 .03437 L
.03437 .03217 L
s
.06466 .02252 m
.06751 .0268 L
.07223 .03289 L
.07374 .03437 L
.07223 .03986 L
.06643 .03437 L
.06466 .03287 L
.06003 .0268 L
.06466 .02252 L
s
.04952 .0488 m
.05244 .04952 L
.05709 .05486 L
.05805 .05709 L
.05709 .05769 L
.05597 .05709 L
.04952 .05076 L
.04923 .04952 L
.04952 .0488 L
s
.04194 .03395 m
.04212 .03437 L
.04194 .03806 L
.03458 .03437 L
.04194 .03395 L
s
.06466 .02413 m
.06608 .0268 L
.06466 .03089 L
.06191 .0268 L
.06466 .02413 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00^@3oool3000000@0oooo0`00002U0?ooo`00^03oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000002T0?ooo`00^03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0:80oooo002h0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0XP3oool00;P0oooo00<000000?ooo`3oool01P3oool200000:D0oooo002g
0?ooo`D000001`3oool00`000000oooo0?ooo`2R0?ooo`00^03oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`000000Y03oool00<00oooo0`00002U0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`005P3ooooo0000058000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool001H0
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3o
ool001H0oooo00<000000?ooo`3oool01`3oool3000000050?ooo`00000000000000003oool01P00
00020?ooo`D0000000D0oooo000000000000oooo000000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`000000oooo0`0000040?ooo`030000003oool0oooo0?l0oooo5`3oool100000040
oooo000F0?ooo`030000003oool0oooo00L0oooo2@0000000`3oool000000000000200000080oooo
100000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo
0P0000040?ooo`030000003oool0oooo0?l0oooo5P3oool100000040oooo000F0?ooo`030000003o
ool0oooo00P0oooo100000000`3oool000000000000<000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool00P0000000`3oool000000?oo
o`020?ooo`030000003oool0oooo0?l0oooo5P3oool100000040oooo000F0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000002@0000000`3oool0000000000002000000030?ooo`000000
000000H000001@3oool3000000030?ooo`000000oooo0080000000<0oooo0000000000000`000003
0?ooo`030000003oool0oooo0?l0oooo5@3oool100000040oooo000F0?ooo`030000003oool0oooo
00@0oooo3`0000000`3oool0000000000002000000030?ooo`000000000000<0000000<0oooo0000
003oool01@3oool3000000050?ooo`00000000000?ooo`000000103oool2000000<0oooo0P00003o
0?oooaD0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0000000<0oooo0000000000000`0000000`3oool0000000000003000000030?ooo`0000000000
0080000000<0oooo0000003oool00P3oool200000080oooo0P000000103oool000000000003oool2
000000<0oooo0`0000030?ooo`030000003oool0oooo0?l0oooo4P3oool100000040oooo000F0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@0000020?ooo`/0000000@0oooo0000
0000000000001@3oool00`000000oooo0?ooo`0200000080oooo00L000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`3oool0oooo0000003o0?oooa@0oooo0@0000010?ooo`00
5P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0000000<0oooo000000000000
100000000`3oool0000000000003000000030?ooo`0000000000008000000P3oool3000000D0oooo
00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0000000@0oooo00@000000?ooo`3o
ool00000o`3ooolD0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool00`3ooolC00000080
oooo1`0000070?ooo`80000000<0oooo0000003oool00P0000030?ooo`030000003oool0oooo00<0
oooo0P0000000`3oool000000?ooo`3o0?oooa<0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000000T000000P3oool4000000030?ooo`000000000000800000
0P3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000103oool00`000000
oooo0?ooo`040?ooo`800000o`3ooolD0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0
1P3oool=00000080oooo2@0000020?ooo`040000003oool0oooo0?ooo`@0000000H0oooo0000003o
ool000000?ooo`0000040?ooo`030000003oool0oooo0?l0oooo6@3oool100000040oooo000F0?oo
o`030000003oool0oooo00H0oooo0`0000020?ooo`<0000000<0oooo0000000000000P0000020?oo
o`T000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000030?ooo`050000003oool0
oooo0?ooo`000000o`3ooolK0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0103oool5
00000080oooo100000000`3oool0000000000007000000030?ooo`000000oooo00<000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
0000003o0?oooaX0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`030?ooo`80000000<0
oooo0000000000000P0000000`3oool000000000000E000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`040000003oool0oooo00000?l0oooo6P3oool100000040oooo000F0?ooo`030000
003oool0oooo00D0oooo4P0000020?ooo`D00000203oool200000080oooo00<000000?ooo`3oool0
103oool200000?l0oooo6`3oool100000040oooo000F0?ooo`030000003oool0oooo00H0oooo4P00
00020?ooo`8000002`3oool01@000000oooo0?ooo`3oool000000?l0oooo8P3oool100000040oooo
000F0?ooo`030000003oool0oooo00H0oooo200000000`3oool0000000000002000000030?ooo`00
00000000008000000`3oool2000000/0oooo00<000000?ooo`000000o`3ooolS0?ooo`4000000@3o
ool001H0oooo00<000000?ooo`3oool0103oool5000000030?ooo`00000000000080000000<0oooo
0000000000000P0000020?ooo`@0000000D0oooo000000000000oooo0000000;0?ooo`030000003o
ool0oooo0?l0oooo8P3oool100000040oooo000F0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@0000000`3oool0000000000003000000030?ooo`000000000000<0000000<0oooo
000000000000o`3oool`0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0?000000030?ooo`000000oooo00<0000000<0oooo0000003oool0o`3oool_0?oo
o`4000000@3oool001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0300000080
oooo100000000`3oool000000000000200000080oooo00H000000?ooo`00000000000?ooo`00003o
0?oooc00oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`040000003oool00000
0?ooo`8000000`3oool4000000040?ooo`000000000000000080oooo0P000000103oool000000?oo
o`00003o0?ooobl0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`L000000P3o
ool400000080oooo0`0000030?ooo`050000003oool000000?ooo`000000o`3oool^0?ooo`400000
0@3oool001H0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000<000000P3o
ool3000000<0oooo0`0000030?ooo`050000003oool000000?ooo`000000o`3oool]0?ooo`400000
0@3oool001H0oooo00<000000?ooo`3oool01P3oool4000000040?ooo`000000000000000080oooo
100000020?ooo`80000000@0oooo0000003oool000000`3oool00`000000oooo0?ooo`3o0?ooob`0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`070?ooo`8000000`3oool300000080oooo
1@0000001P3oool000000?ooo`000000oooo00000?l0oooo<P3oool100000040oooo000F0?ooo`03
0000003oool0oooo00L0oooo0`0000020?ooo`H0000000@0oooo00000000000000000P3oool00`00
0000oooo0000003o0?oooc<0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`080?ooo`@0
00000P3oool3000000<0oooo0P0000030?ooo`800000o`3ooolc0?ooo`4000000@3oool001H0oooo
00<000000?ooo`3oool01P3oool700000080oooo0`0000030?ooo`<000000`3oool00`000000oooo
0?ooo`3o0?oooc00oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool000000080oooo0`000000103oool000000?ooo`0000030?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool0o`3oool`0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool01@3o
ool3000000<0oooo0P0000000`3oool000000?ooo`03000000<0oooo0P0000040?ooo`030000003o
ool0oooo0?l0oooo;`3oool100000040oooo000F0?ooo`030000003oool0oooo00<0oooo0P000000
103oool000000000000000030?ooo`80000000@0oooo000000000000oooo0`000000103oool00000
0?ooo`0000030?ooo`030000003oool0oooo0?l0oooo;`3oool100000040oooo000F0?ooo`030000
003oool0oooo00@0oooo0P000000103oool000000000000000030?ooo`800000103oool00`000000
oooo000000030?ooo`<00000o`3ooolb0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0300000080oooo0P0000040?ooo`030000003oool0oooo0?l0oooo
=`3oool100000040oooo000F0?ooo`030000003oool0oooo00H0oooo00H000000?ooo`3oool0oooo
0000003oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooocH0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`070?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`050000003oool0oooo0?ooo`000000o`3ooolh0?ooo`4000000@3oool0
01H0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D00000
0?ooo`3oool0oooo0000003o0?ooocL0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`08
0?ooo`050000003oool0oooo0?ooo`0000001P3oool300000?l0oooo>03oool100000040oooo000F
0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo0?l0oooo=P3oool100000040oooo000F0?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool00000o`3ooom00?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`00003o0?oood00oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0;
0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?oooc@0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`0G0?ooo`800000o`3ooole0?ooo`4000000@3oool001H0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0000003o0?oooc@0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000o`3ooold0?ooo`400000
0@3oool001H0oooo00<000000?ooo`3oool03`3oool2000000L0oooo0`00003o0?oooc<0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo0P00
003o0?oooc80oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
00000?l0oooo?03oool100000040oooo000F0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`0000000000o`3ooolj0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool04@3oool01000
0000oooo0?ooo`00003o0?ooocT0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0:0?oo
o`8000001@3oool010000000oooo0?ooo`00003o0?ooocT0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`080?ooo`80000000<0oooo0000003oool01@3oool010000000oooo0?ooo`00003o
0?ooocP0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
000000L0oooo00@000000?ooo`3oool00000o`3ooolg0?ooo`4000000@3oool001H0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool000000?l0oooo=`3o
ool100000040oooo000F0?ooo`030000003oool0oooo00P0oooo100000090?ooo`<00000o`3ooolf
0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?oo
ocl0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3oooln0?ooo`40
00000@3oool001H0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo0?l0oooo<@3oool100000040oooo000F0?ooo`030000003oool0oooo00d0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`3o0?oooc40oooo0@0000010?ooo`00
5P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000
oooo0?ooo`3o0?oooc40oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0>0?ooo`800000
0P3oool00`000000oooo0?ooo`3o0?ooocT0oooo0@0000010?ooo`005P3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo00000?l0oooo>P3oool100000040oooo000F0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00003o0?ooocT0oooo
0@0000010?ooo`005P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000L0oooo
00@000000?ooo`3oool00000o`3ooolh0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`000000o`3ooolh0?ooo`40
00000@3oool001H0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo00L0oooo
0P00003o0?ooocP0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0:0?ooo`800000o`3o
oom20?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool0
01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooch0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`0=0?ooo`800000o`3ooolo0?ooo`4000000@3oool001H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooch0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`001@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo00040?ooo`H00000303oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo00030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3o
oom>0?ooo`4000000@3oool000<0oooo2000000;0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`4000000@3oool000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@00
00010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0
oooo0@0000010?ooo`005P3ooooo0000058000000@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10.1749, -9.79282, 0.49017, \
0.49017}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0116596 0.00757117 0.0116596 0.00757117 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -12.5625 -8 ]
[-0.01875 .5 0 8 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t3) show
1.000 setlinewidth
grestore
0 0 m
0 1 L
s
gsave
-0.01875 .5 -75.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t1) show
1.000 setlinewidth
grestore
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.06466 .02417 m
.06896 .0268 L
.06466 .0311 L
.06362 .0268 L
.06466 .02417 L
s
.03437 .06933 m
.03698 .07223 L
.03437 .07502 L
.03251 .07223 L
.03437 .06933 L
s
.04194 .06143 m
.04315 .06466 L
.04194 .06597 L
.04011 .06466 L
.04194 .06143 L
s
.05709 .0343 m
.06287 .03437 L
.05709 .04112 L
.05698 .03437 L
.05709 .0343 L
s
.06466 .02262 m
.07074 .0268 L
.06466 .03335 L
.06247 .0268 L
.06466 .02262 L
s
.04276 .01923 m
.04194 .02299 L
.03743 .01923 L
s
.06466 .11008 m
.06672 .11008 L
.06466 .11209 L
.06465 .11008 L
.06466 .11008 L
s
.03437 .10314 m
.0361 .11008 L
.03437 .11114 L
.03245 .11008 L
.03437 .10314 L
s
.07223 .10199 m
.07365 .10251 L
.07223 .10536 L
.07167 .10251 L
.07223 .10199 L
s
.04194 .09647 m
.04379 .10251 L
.04194 .1049 L
.03497 .10251 L
.04194 .09647 L
s
.04952 .0875 m
.05127 .09494 L
.04952 .09675 L
.04342 .09494 L
.04952 .0875 L
s
.05709 .07936 m
.06405 .0798 L
.05787 .08737 L
.05709 .08819 L
.04965 .08737 L
.05675 .0798 L
.05709 .07936 L
s
.03437 .06725 m
.03888 .07223 L
.03437 .07705 L
.03081 .07223 L
.03437 .06725 L
s
.04194 .05824 m
.04549 .06466 L
.04194 .06853 L
.03739 .06466 L
.04194 .05824 L
s
.06466 .02152 m
.07215 .0268 L
.06555 .03437 L
.06466 .03533 L
.05921 .04194 L
.05709 .04493 L
.0534 .04194 L
.05485 .03437 L
.05709 .03274 L
.06146 .0268 L
.06466 .02152 L
s
.03437 .01991 m
.03951 .0268 L
.03437 .02788 L
.03373 .0268 L
.03437 .01991 L
s
.07614 .01923 m
.07223 .02667 L
.07008 .01923 L
s
.0441 .01923 m
.04194 .02515 L
.03498 .01923 L
s
.04952 .12265 m
.057 .12523 L
.04952 .13167 L
.04757 .12523 L
.04952 .12265 L
s
.05709 .11495 m
.06408 .11766 L
.05709 .12514 L
.05438 .11766 L
.05709 .11495 L
s
.06466 .10694 m
.07158 .11008 L
.06466 .11708 L
.06178 .11008 L
.06466 .10694 L
s
.07223 .09908 m
.0775 .10251 L
.07223 .10947 L
.06877 .10251 L
.07223 .09908 L
s
.0798 .09322 m
.08248 .09494 L
.0798 .09815 L
.07839 .09494 L
.0798 .09322 L
s
.08737 .08454 m
.08948 .08737 L
.08737 .09072 L
.0844 .08737 L
.08737 .08454 L
s
.0268 .07721 m
.03208 .0798 L
.0268 .08421 L
.02376 .0798 L
.0268 .07721 L
s
.03437 .06553 m
.04046 .07223 L
.03437 .0787 L
.02928 .07223 L
.03437 .06553 L
s
.07223 .06211 m
.07572 .06466 L
.0736 .07223 L
.07223 .0737 L
.06635 .0798 L
.06466 .08164 L
.05972 .08737 L
.05709 .09014 L
.0529 .09494 L
.04952 .09846 L
.04549 .10251 L
.04194 .10693 L
.0386 .11008 L
.03437 .11321 L
.02967 .11008 L
.03289 .10251 L
.03437 .10121 L
.04135 .09494 L
.04194 .09417 L
.04807 .08737 L
.04952 .08583 L
.05515 .0798 L
.05709 .07729 L
.06231 .07223 L
.06466 .06944 L
.06939 .06466 L
.07223 .06211 L
s
.04194 .05571 m
.04952 .05132 L
.05116 .05709 L
.04952 .06093 L
.04729 .06466 L
.04194 .07047 L
.03538 .06466 L
.04116 .05709 L
.04194 .05571 L
s
.0798 .04779 m
.08414 .04952 L
.0798 .05361 L
.07945 .04952 L
.0798 .04779 L
s
.08737 .03559 m
.08986 .04194 L
.08737 .04578 L
.08397 .04194 L
.08737 .03559 L
s
.0268 .04018 m
.02886 .04194 L
.0268 .04697 L
.02376 .04194 L
.0268 .04018 L
s
.14037 .03274 m
.14791 .03437 L
.14037 .04177 L
.13845 .03437 L
.14037 .03274 L
s
.09494 .02725 m
.09713 .03437 L
.09494 .03728 L
.08833 .03437 L
.09494 .02725 L
s
.14794 .02335 m
.15546 .0268 L
.14794 .03434 L
.1459 .0268 L
.14794 .02335 L
s
.07871 .01923 m
.07324 .0268 L
.07223 .02862 L
.06723 .03437 L
.06466 .03714 L
.06111 .04194 L
.05709 .04785 L
.0512 .04194 L
.05311 .03437 L
.05709 .03139 L
.06051 .0268 L
.06466 .02063 L
.06794 .01923 L
s
.04528 .01923 m
.04196 .0268 L
.04194 .02682 L
.03437 .03104 L
.03175 .0268 L
.03296 .01923 L
s
.04952 .15875 m
.05479 .16308 L
.04952 .16578 L
.048 .16308 L
.04952 .15875 L
s
.05709 .15067 m
.06252 .15551 L
.05709 .16141 L
.05177 .15551 L
.05709 .15067 L
s
.06466 .14194 m
.07005 .14794 L
.06466 .15358 L
.05959 .14794 L
.06466 .14194 L
s
.07223 .13354 m
.0775 .14037 L
.07223 .14589 L
.06606 .14037 L
.07223 .13354 L
s
.0798 .12589 m
.08403 .1328 L
.0798 .13772 L
.07303 .1328 L
.0798 .12589 L
s
.08737 .11714 m
.09494 .11434 L
.09585 .11766 L
.09494 .11944 L
.09215 .12523 L
.08737 .12983 L
.08035 .12523 L
.0868 .11766 L
.08737 .11714 L
s
.0268 .11099 m
.02962 .11766 L
.0268 .12192 L
.02089 .11766 L
.0268 .11099 L
s
.0798 .08886 m
.08726 .09494 L
.08013 .10251 L
.0798 .10294 L
.07424 .11008 L
.07223 .11194 L
.06654 .11766 L
.06466 .11969 L
.05944 .12523 L
.05709 .12774 L
.05158 .1328 L
.04952 .1347 L
.04444 .14037 L
.04194 .14393 L
.03558 .14794 L
.03437 .14859 L
.03134 .14794 L
.03099 .14037 L
.03437 .13629 L
.03835 .1328 L
.04194 .13003 L
.04558 .12523 L
.04952 .1203 L
.05215 .11766 L
.05709 .11274 L
.05965 .11008 L
.06466 .10467 L
.06665 .10251 L
.07223 .09688 L
.07478 .09494 L
.0798 .08886 L
s
.08737 .08046 m
.0931 .08737 L
.08737 .09485 L
.08092 .08737 L
.08737 .08046 L
s
.14037 .06852 m
.14546 .07223 L
.14037 .07655 L
.13747 .07223 L
.14037 .06852 L
s
.14794 .06066 m
.15352 .06466 L
.14794 .06987 L
.1443 .06466 L
.14794 .06066 L
s
.07223 .05936 m
.0785 .06466 L
.07564 .07223 L
.07223 .07578 L
.06821 .0798 L
.06466 .08358 L
.06136 .08737 L
.05709 .09185 L
.05438 .09494 L
.04952 .10002 L
.04704 .10251 L
.04194 .10875 L
.04057 .11008 L
.03437 .11503 L
.02721 .11008 L
.03109 .10251 L
.03437 .09972 L
.03982 .09494 L
.04194 .09331 L
.04671 .08737 L
.04952 .08436 L
.05374 .0798 L
.05709 .07547 L
.06038 .07223 L
.06466 .06714 L
.06697 .06466 L
.07223 .05936 L
s
.15551 .05165 m
.16147 .05709 L
.15551 .06304 L
.15077 .05709 L
.15551 .05165 L
s
.16308 .04352 m
.16821 .04952 L
.16308 .05563 L
.15736 .04952 L
.16308 .04352 L
s
.0268 .03508 m
.03268 .04194 L
.02823 .04952 L
.0268 .05281 L
.02013 .04952 L
.02057 .04194 L
.0268 .03508 L
s
.17065 .03407 m
.17823 .02822 L
.18238 .03437 L
.17823 .04015 L
.17643 .04194 L
.17065 .04699 L
.16465 .04194 L
.17038 .03437 L
.17065 .03407 L
s
.1858 .02164 m
.18683 .0268 L
.1858 .02807 L
.18067 .0268 L
.1858 .02164 L
s
.11766 .01946 m
.12241 .0268 L
.11766 .02885 L
.11492 .0268 L
.11766 .01946 L
s
.16377 .01923 m
.16308 .01967 L
.15794 .0268 L
.15551 .02939 L
.15043 .03437 L
.14794 .03708 L
.1432 .04194 L
.14037 .04468 L
.13565 .04952 L
.1328 .05091 L
.12789 .05709 L
.12523 .05958 L
.11878 .05709 L
.12087 .04952 L
.12523 .04701 L
.13037 .04194 L
.1328 .03861 L
.13593 .03437 L
.14037 .03047 L
.14375 .0268 L
.14794 .02105 L
.15211 .01923 L
s
.12977 .01923 m
.12523 .02528 L
.11808 .01923 L
s
.10483 .01923 m
.10643 .0268 L
.10251 .03053 L
.09966 .03437 L
.09494 .04037 L
.09329 .04194 L
.0884 .04952 L
.08737 .05159 L
.08368 .05709 L
.0798 .06231 L
.07546 .05709 L
.07717 .04952 L
.0798 .04265 L
.08044 .04194 L
.08628 .03437 L
.08737 .03319 L
.09333 .0268 L
.09494 .02405 L
.10176 .01923 L
s
.08065 .01923 m
.0798 .01962 L
.07428 .0268 L
.07223 .03038 L
.06878 .03437 L
.06466 .03909 L
.06281 .04194 L
.05805 .04952 L
.05709 .05043 L
.05295 .05709 L
.04952 .06376 L
.04892 .06466 L
.04194 .07219 L
.04191 .07223 L
.0348 .0798 L
.03437 .08016 L
.0272 .08737 L
.0268 .08805 L
.01998 .08737 L
.02073 .0798 L
.0268 .07384 L
.02774 .07223 L
.03353 .06466 L
.03437 .06393 L
.03979 .05709 L
.04194 .05364 L
.04766 .04952 L
.04942 .04194 L
.04952 .04102 L
.05149 .03437 L
.05709 .03014 L
.05959 .0268 L
.06466 .01987 L
.06619 .01923 L
s
.04638 .01923 m
.04306 .0268 L
.04194 .02832 L
.03437 .03404 L
.02998 .0268 L
.03099 .01923 L
s
.03437 .24373 m
.03676 .24637 L
.03437 .24791 L
.03323 .24637 L
.03437 .24373 L
s
.04194 .23657 m
.04361 .23879 L
.04194 .24097 L
.03957 .23879 L
.04194 .23657 L
s
.04952 .2289 m
.05063 .23122 L
.04952 .23268 L
.04721 .23122 L
.04952 .2289 L
s
.03437 .20838 m
.03502 .20851 L
.03437 .2116 L
.03427 .20851 L
.03437 .20838 L
s
.08737 .1753 m
.089 .17823 L
.08737 .17981 L
.086 .17823 L
.08737 .1753 L
s
.09494 .17021 m
.09505 .17065 L
.09494 .1709 L
.09296 .17065 L
.09494 .17021 L
s
.12523 .15524 m
.12573 .15551 L
.12523 .15651 L
.12493 .15551 L
.12523 .15524 L
s
.1328 .14703 m
.1338 .14794 L
.1328 .14885 L
.13225 .14794 L
.1328 .14703 L
s
.14794 .13142 m
.14814 .1328 L
.14794 .13308 L
.14693 .1328 L
.14794 .13142 L
s
.09494 .12878 m
.09989 .1328 L
.09533 .14037 L
.09494 .14085 L
.08857 .14794 L
.08737 .14888 L
.08112 .15551 L
.0798 .15706 L
.07381 .16308 L
.07223 .16492 L
.06679 .17065 L
.06466 .17353 L
.05964 .17823 L
.05709 .18136 L
.04965 .17823 L
.0546 .17065 L
.05709 .16872 L
.06179 .16308 L
.06466 .15971 L
.06832 .15551 L
.07223 .15118 L
.07525 .14794 L
.0798 .14301 L
.082 .14037 L
.08737 .1343 L
.08976 .1328 L
.09494 .12878 L
s
.10251 .12118 m
.10453 .12523 L
.10251 .12855 L
.09925 .12523 L
.10251 .12118 L
s
.09494 .09142 m
.10088 .09494 L
.09692 .10251 L
.09494 .1053 L
.09211 .11008 L
.08737 .11387 L
.08343 .11766 L
.0798 .12202 L
.07722 .12523 L
.07223 .13028 L
.06967 .1328 L
.06466 .13815 L
.06248 .14037 L
.05709 .14627 L
.05517 .14794 L
.04952 .15281 L
.04671 .15551 L
.04194 .16303 L
.04187 .16308 L
.03437 .16685 L
.03068 .16308 L
.03221 .15551 L
.03437 .15365 L
.04153 .14794 L
.04194 .14763 L
.04697 .14037 L
.04952 .13742 L
.05429 .1328 L
.05709 .13018 L
.0617 .12523 L
.06466 .12206 L
.06874 .11766 L
.07223 .11418 L
.0767 .11008 L
.0798 .10614 L
.08273 .10251 L
.08737 .09782 L
.09233 .09494 L
.09494 .09142 L
s
.17823 .08463 m
.18092 .08737 L
.17823 .09087 L
.17624 .08737 L
.17823 .08463 L
s
.10251 .08231 m
.10508 .08737 L
.10251 .09185 L
.09902 .08737 L
.10251 .08231 L
s
.08737 .05801 m
.09347 .06466 L
.09186 .07223 L
.08737 .07701 L
.08442 .0798 L
.0798 .08531 L
.07867 .08737 L
.07223 .09485 L
.07213 .09494 L
.06473 .10251 L
.06466 .1026 L
.0577 .11008 L
.05709 .11072 L
.05008 .11766 L
.04952 .11821 L
.04372 .12523 L
.04194 .12751 L
.03476 .1328 L
.03437 .13309 L
.02715 .14037 L
.0268 .14121 L
.02014 .14037 L
.02162 .1328 L
.0268 .12833 L
.02805 .12523 L
.03305 .11766 L
.03437 .11683 L
.04194 .11058 L
.04238 .11008 L
.04856 .10251 L
.04952 .10155 L
.05583 .09494 L
.05709 .09352 L
.06295 .08737 L
.06466 .08542 L
.07006 .0798 L
.07223 .07772 L
.07764 .07223 L
.0798 .06709 L
.08155 .06466 L
.08737 .05801 L
s
.23122 .04877 m
.23196 .04952 L
.23122 .05014 L
.23085 .04952 L
.23122 .04877 L
s
.17823 .04496 m
.18539 .04952 L
.18054 .05709 L
.17823 .05939 L
.1723 .06466 L
.17065 .06636 L
.16519 .07223 L
.16308 .07456 L
.15776 .0798 L
.15551 .08278 L
.14963 .08737 L
.14794 .08947 L
.14037 .09413 L
.1397 .08737 L
.14037 .08677 L
.14722 .0798 L
.14794 .07899 L
.15305 .07223 L
.15551 .06966 L
.15949 .06466 L
.16308 .06081 L
.16638 .05709 L
.17065 .0517 L
.17279 .04952 L
.17823 .04496 L
s
.23879 .04093 m
.23928 .04194 L
.23879 .04251 L
.23785 .04194 L
.23879 .04093 L
s
.1858 .03648 m
.19153 .04194 L
.1858 .0489 L
.18209 .04194 L
.1858 .03648 L
s
.24637 .03416 m
.24639 .03437 L
.24637 .03443 L
.24546 .03437 L
.24637 .03416 L
s
.19337 .03146 m
.19509 .03437 L
.19337 .03804 L
.18848 .03437 L
.19337 .03146 L
s
.10251 .03419 m
.10613 .03437 L
.10842 .04194 L
.1034 .04952 L
.10251 .04998 L
.09808 .05709 L
.09494 .0614 L
.08855 .05709 L
.09156 .04952 L
.09494 .04395 L
.09702 .04194 L
.10237 .03437 L
.10251 .03419 L
s
.18142 .01923 m
.17823 .02297 L
.1755 .0268 L
.17065 .03108 L
.16775 .03437 L
.16308 .04005 L
.16114 .04194 L
.15551 .04767 L
.15356 .04952 L
.14794 .05551 L
.1464 .05709 L
.14037 .06291 L
.13719 .06466 L
.1328 .06913 L
.13057 .07223 L
.12523 .07782 L
.11846 .07223 L
.12364 .06466 L
.12523 .06415 L
.13189 .05709 L
.1328 .05577 L
.13831 .04952 L
.14037 .04737 L
.14576 .04194 L
.14794 .03965 L
.15273 .03437 L
.15551 .03168 L
.16025 .0268 L
.16308 .02266 L
.16779 .01923 L
s
.14835 .01923 m
.14794 .01939 L
.14173 .0268 L
.14037 .02832 L
.13363 .03437 L
.1328 .03544 L
.12755 .04194 L
.12523 .04404 L
.11766 .04643 L
.11285 .04194 L
.11584 .03437 L
.11766 .0332 L
.12523 .02791 L
.12638 .0268 L
.1328 .01942 L
.13331 .01923 L
s
.09823 .01923 m
.09494 .02158 L
.09175 .0268 L
.08737 .03158 L
.08476 .03437 L
.0798 .04031 L
.07787 .04194 L
.07519 .04952 L
.07223 .05652 L
.07176 .05709 L
.06488 .06466 L
.06466 .06491 L
.05858 .07223 L
.05709 .07371 L
.0524 .0798 L
.04952 .08294 L
.04542 .08737 L
.04194 .09325 L
.03834 .09494 L
.03437 .09831 L
.02922 .10251 L
.0268 .10679 L
.01961 .10251 L
.02261 .09494 L
.0268 .09106 L
.02879 .08737 L
.03437 .08149 L
.03631 .0798 L
.04194 .07369 L
.04339 .07223 L
.04952 .06579 L
.05054 .06466 L
.05465 .05709 L
.05709 .05294 L
.06034 .04952 L
.06451 .04194 L
.06466 .04168 L
.07032 .03437 L
.07223 .03212 L
.0753 .0268 L
.0798 .0205 L
.08236 .01923 L
s
.0646 .01923 m
.05868 .0268 L
.05709 .02893 L
.04988 .03437 L
.04952 .03509 L
.04803 .04194 L
.04518 .04952 L
.04194 .05195 L
.03848 .05709 L
.03437 .06236 L
.03167 .06466 L
.0268 .07103 L
.01958 .06466 L
.0237 .05709 L
.0268 .05472 L
.03031 .04952 L
.03437 .04467 L
.03494 .04194 L
.03609 .03437 L
.04194 .02976 L
.04408 .0268 L
.04745 .01923 L
s
.02885 .01923 m
.02814 .0268 L
.0268 .03043 L
.01961 .0268 L
.0197 .01923 L
s
.04952 .14078 m
.04987 .14794 L
.04952 .14816 L
.04847 .14794 L
.04952 .14078 L
s
.05709 .13296 m
.05907 .14037 L
.05709 .14254 L
.0498 .14037 L
.05709 .13296 L
s
.03437 .11908 m
.04171 .12523 L
.03437 .1303 L
.0306 .12523 L
.03437 .11908 L
s
.04194 .11268 m
.0478 .11766 L
.04194 .12499 L
.03588 .11766 L
.04194 .11268 L
s
.04952 .10324 m
.05578 .11008 L
.04952 .1162 L
.04415 .11008 L
.04952 .10324 L
s
.08737 .10101 m
.09153 .10251 L
.08785 .11008 L
.08737 .11046 L
.08013 .11766 L
.0798 .11808 L
.07423 .12523 L
.07223 .12723 L
.06651 .1328 L
.06466 .13477 L
.05725 .1328 L
.06414 .12523 L
.06466 .12466 L
.07115 .11766 L
.07223 .1166 L
.07951 .11008 L
.0798 .1097 L
.08577 .10251 L
.08737 .10101 L
s
.05709 .09528 m
.06283 .10251 L
.05709 .10871 L
.05024 .10251 L
.05709 .09528 L
s
.07223 .0797 m
.0798 .07254 L
.08091 .0798 L
.0798 .08127 L
.07676 .08737 L
.07223 .09279 L
.07001 .09494 L
.06466 .10052 L
.05742 .09494 L
.0646 .08737 L
.06466 .08731 L
.07212 .0798 L
.07223 .0797 L
s
.04952 .06756 m
.05672 .07223 L
.05105 .0798 L
.04952 .08148 L
.04412 .08737 L
.04194 .09262 L
.03679 .09494 L
.03437 .09689 L
.02689 .10251 L
.0268 .10267 L
.02127 .10251 L
.02642 .09494 L
.0268 .09446 L
.03022 .08737 L
.03437 .08284 L
.03775 .0798 L
.04194 .07519 L
.04492 .07223 L
.04952 .06756 L
s
.08737 .06419 m
.088 .06466 L
.08811 .07223 L
.08737 .07308 L
.08 .07223 L
.08667 .06466 L
.08737 .06419 L
s
.14037 .05108 m
.14193 .05709 L
.14037 .05843 L
.1371 .05709 L
.14037 .05108 L
s
.14794 .04294 m
.14967 .04952 L
.14794 .05133 L
.14197 .04952 L
.14794 .04294 L
s
.12523 .03043 m
.13096 .03437 L
.12523 .04106 L
.12019 .03437 L
.12523 .03043 L
s
.04194 .03121 m
.04809 .03437 L
.04663 .04194 L
.04272 .04952 L
.04194 .05012 L
.03715 .05709 L
.03437 .06071 L
.02956 .06466 L
.0268 .06817 L
.02096 .06466 L
.02676 .05709 L
.0268 .05702 L
.03229 .04952 L
.03437 .04744 L
.03655 .04194 L
.03785 .03437 L
.04194 .03121 L
s
.16308 .0264 m
.17065 .02014 L
.17179 .0268 L
.17065 .02786 L
.1651 .03437 L
.16308 .0369 L
.15783 .04194 L
.15551 .04424 L
.14878 .04194 L
.15521 .03437 L
.15551 .03408 L
.16283 .0268 L
.16308 .0264 L
s
.1328 .02103 m
.1394 .0268 L
.1328 .03245 L
.12893 .0268 L
.1328 .02103 L
s
.14372 .01923 m
.14037 .02588 L
.13768 .01923 L
s
.09525 .01923 m
.09494 .01944 L
.09024 .0268 L
.08737 .03001 L
.08325 .03437 L
.0798 .03936 L
.07527 .04194 L
.07318 .04952 L
.07223 .05216 L
.06877 .05709 L
.06466 .06197 L
.06289 .06466 L
.05709 .0718 L
.05226 .06466 L
.05644 .05709 L
.05709 .05592 L
.0626 .04952 L
.06466 .04514 L
.06715 .04194 L
.07194 .03437 L
.07223 .03402 L
.07634 .0268 L
.0798 .02152 L
.08413 .01923 L
s
.06318 .01923 m
.05775 .0268 L
.05709 .02769 L
.04952 .03317 L
.04509 .0268 L
.04854 .01923 L
s
.03437 .12264 m
.03814 .12523 L
.03437 .12687 L
.03337 .12523 L
.03437 .12264 L
s
.04194 .11527 m
.04495 .11766 L
.04194 .12185 L
.03892 .11766 L
.04194 .11527 L
s
.04952 .10541 m
.05367 .11008 L
.04952 .11401 L
.04611 .11008 L
.04952 .10541 L
s
.05709 .09756 m
.06072 .10251 L
.05709 .10647 L
.0524 .10251 L
.05709 .09756 L
s
.06466 .08985 m
.06771 .09494 L
.06466 .09818 L
.05978 .09494 L
.06466 .08985 L
s
.07223 .08231 m
.07469 .08737 L
.07223 .09046 L
.06699 .08737 L
.07223 .08231 L
s
.04952 .06943 m
.0546 .07223 L
.04961 .0798 L
.04952 .0799 L
.04276 .08737 L
.04194 .09008 L
.03498 .09494 L
.03437 .09539 L
.03021 .09494 L
.03162 .08737 L
.03437 .08426 L
.03924 .0798 L
.04194 .07679 L
.04664 .07223 L
.04952 .06943 L
s
.05709 .05922 m
.06065 .06466 L
.05709 .06914 L
.05425 .06466 L
.05709 .05922 L
s
.06466 .05119 m
.06513 .05709 L
.06466 .0577 L
.05999 .05709 L
.06466 .05119 L
s
.03437 .04978 m
.03569 .05709 L
.03437 .05886 L
.02958 .05709 L
.03437 .04978 L
s
.12523 .03353 m
.12697 .03437 L
.12523 .03686 L
.12404 .03437 L
.12523 .03353 L
s
.04194 .03275 m
.04593 .03437 L
.04512 .04194 L
.04194 .0477 L
.03823 .04194 L
.0397 .03437 L
.04194 .03275 L
s
.1328 .0239 m
.1355 .0268 L
.1328 .02852 L
.13197 .0268 L
.1328 .0239 L
s
.04952 .01934 m
.0567 .0268 L
.04952 .03169 L
.04611 .0268 L
.04952 .01934 L
s
.09189 .01923 m
.0887 .0268 L
.08737 .02835 L
.08162 .03437 L
.0798 .03784 L
.07411 .03437 L
.07742 .0268 L
.0798 .02275 L
.08618 .01923 L
s
.06173 .01923 m
.05709 .02638 L
.04973 .01923 L
s
.04952 .1088 m
.05053 .11008 L
.04952 .1109 L
.04885 .11008 L
.04952 .1088 L
s
.05709 .1012 m
.05773 .10251 L
.05709 .10324 L
.05586 .10251 L
.05709 .1012 L
s
.03437 .08589 m
.04093 .08737 L
.03437 .09328 L
.03312 .08737 L
.03437 .08589 L
s
.04194 .07864 m
.04724 .0798 L
.04194 .08619 L
.04092 .0798 L
.04194 .07864 L
s
.04952 .0717 m
.05143 .07223 L
.04952 .07693 L
.04891 .07223 L
.04952 .0717 L
s
.04194 .03462 m
.04325 .04194 L
.04194 .04443 L
.04031 .04194 L
.04194 .03462 L
s
.0798 .02439 m
.08693 .0268 L
.0798 .03408 L
.07862 .0268 L
.0798 .02439 L
s
.04952 .02019 m
.05531 .0268 L
.04952 .03019 L
.04719 .0268 L
.04952 .02019 L
s
.06014 .01923 m
.05709 .02491 L
.05146 .01923 L
s
.04952 .02132 m
.05352 .0268 L
.04952 .02848 L
.04841 .0268 L
.04952 .02132 L
s
.05817 .01923 m
.05709 .02297 L
.05393 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00^@3oool3000000@0oooo0`00002U0?ooo`00^03oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000002T0?ooo`00^03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0:80oooo002h0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0XP3oool00;P0oooo00<000000?ooo`3oool01P3oool200000:D0oooo002g
0?ooo`D000001`3oool00`000000oooo0?ooo`2R0?ooo`00^03oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`000000Y03oool00<00oooo0`00002U0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`005P3ooooo0000058000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>
0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool001H0
oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0
o`3ooom>0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3o
ool001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04000000030?ooo`000000
000000P0000000<0oooo000000000000100000000`3oool0000000000002000000<0oooo00@00000
0?ooo`3oool0oooo0P0000000`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`@00000
0`3oool00`000000oooo0?ooo`3o0?oooa40oooo0@0000010?ooo`005P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0000000<0oooo0000003oool00`0000020?ooo`@0000000<0
oooo0000003oool00P3oool6000000030?ooo`000000000000<000000`3oool400000080oooo00<0
00000?ooo`000000o`3ooolB0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`04000000030?ooo`000000000000`0000000<0oooo0000003oool00P000002
0?ooo`070000003oool0oooo0000003oool000000?ooo`04000000030?ooo`000000000000<00000
00<0oooo0000000000000P3oool010000000oooo0000003oool200000?l0oooo4P3oool100000040
oooo000F0?ooo`030000003oool0oooo00<0oooo0P0000000`3oool000000000000@000000030?oo
o`000000000000<000000P3oool00`000000oooo0?ooo`0<00000080oooo0`0000020?ooo`030000
003oool0000000<00000o`3ooolB0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool01@3o
ool<000000030?ooo`000000000000X0000000<0oooo0000003oool0103oool3000000030?ooo`00
000000000080000000<0oooo0000000000000`0000020?ooo`D00000103oool00`000000oooo0?oo
o`3o0?ooo`d0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
000000d0000000<0oooo0000000000000`0000000`3oool0000000000002000000<0oooo3P000002
0?ooo`<000000`3oool00`000000oooo0000000200000100oooo0P00003l0?ooo`4000000@3oool0
01H0oooo00<000000?ooo`3oool01@3oool010000000oooo0000003oool<000000030?ooo`000000
000000<0000000H0oooo00000000000000000?ooo`0000030?ooo`030000003oool0000000<00000
00<0oooo0000003oool0100000020?ooo`<000000`3oool010000000oooo0000003oool200000?l0
oooo3`3oool100000040oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
3P0000020?ooo`040000003oool0000000000080oooo0P0000020?ooo`030000003oool0000000<0
oooo0`0000020?ooo`<0000000<0oooo0000003oool00P0000000`3oool000000?ooo`020?ooo`80
000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`3m0?ooo`4000000@3oool001H0oooo
00<000000?ooo`3oool00`3oool01@000000oooo000000000000oooo00`000000P3oool400000004
0?ooo`0000000000000000<0oooo00<000000?ooo`0000000P3oool3000000<0oooo2@0000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3m0?oo
o`4000000@3oool001H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0300000003
0?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool3000000<0
oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`030?ooo`<000000`3oool00`00
0000oooo00000003000000050?ooo`00000000000?ooo`000000o`3ooolA0?ooo`4000000@3oool0
01H0oooo00<000000?ooo`3oool00`3oool2000000040?ooo`000000000000000080oooo0`000002
0?ooo`<000000P3oool7000000<0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`000002
0?ooo`@000000P3oool01@000000oooo000000000000oooo008000003P3oool200000?l0oooo0P3o
ool100000040oooo000F0?ooo`030000003oool0oooo00D0oooo100000000`3oool0000000000002
00000080oooo0`0000020?ooo`@0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000P0000001`3oool000000000
003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`3o0?oooa40oooo0@0000010?ooo`00
5P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000000`0000000`3oool00000
00000002000000030?ooo`00000000000080000000<0oooo0000000000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080000000P0oooo000000000000oooo0000003oool00000
0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`3o0?oooa40oooo0@000001
0?ooo`005P3oool00`000000oooo0?ooo`050?ooo`L000000P3oool5000000040?ooo`0000000000
00000080oooo0`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P000000
103oool000000000003oool2000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`3o0?oooa80oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool4
000000030?ooo`00000000000080000000<0oooo0000000000000`000000103oool000000000003o
ool3000000P0oooo0`0000040?ooo`80000000<0oooo0000003oool00`0000040?ooo`030000003o
ool0oooo0?l0oooo4P3oool100000040oooo000F0?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool0000000000008000000030?ooo`00000000000080000000P0oooo00000000000000000?oo
o`000000oooo000000T0oooo0P0000030?ooo`<0000000<0oooo0000000000000P0000040?ooo`80
0000o`3ooolE0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0103oool:000000030?oo
o`000000000000<000000P3oool2000000050?ooo`00000000000?ooo`000000203oool00`000000
oooo0?ooo`020?ooo`080000003oool0oooo0000003oool000000?ooo`0000040?ooo`030000003o
ool0oooo0?l0oooo5@3oool100000040oooo000F0?ooo`030000003oool0oooo00H0oooo10000000
0`3oool000000000000600000080oooo100000000`3oool00000000000090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
o`3ooolH0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`00
0000000000P000000P3oool7000000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0000
003oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0o`3ooolG0?ooo`400000
0@3oool001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000004000000030?ooo`00
0000000000<000000P3oool400000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`00
0000oooo0080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo0?l0oooo603o
ool100000040oooo000F0?ooo`030000003oool0oooo00@0oooo4P0000020?ooo`8000003@3oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000o`3ooolK0?ooo`4000000@3o
ool001H0oooo00<000000?ooo`3oool0103oool3000000050?ooo`00000000000000003oool01000
00000`3oool0000000000003000000050?ooo`00000000000?ooo`000000103oool00`000000oooo
0?ooo`0;0?ooo`050000003oool0oooo0?ooo`000000o`3ooolL0?ooo`4000000@3oool001H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0300000080oooo100000020?ooo`L00000
00@0oooo00000000000000000P3oool2000000d0oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`3o0?oooa80oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`030?oooa40
00000P3oool4000000070?ooo`00000000000?ooo`000000oooo0000000;0?ooo`040000003oool0
oooo000000P0oooo0P00003o0?oooa@0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`06
0?ooo`@0000000@0oooo00000000000000000P3oool3000000030?ooo`000000000000H0000000@0
oooo0000003oool00000303oool00`000000oooo0000000:0?ooo`030000003oool0oooo0?l0oooo
4P3oool100000040oooo000F0?ooo`030000003oool0oooo00D0oooo200000000`3oool000000000
000300000080oooo0`0000001`3oool000000000003oool000000?ooo`0000003@3oool200000?l0
oooo803oool100000040oooo000F0?ooo`030000003oool0oooo00@0oooo0P0000000`3oool00000
00000009000000030?ooo`000000000000@0000000@0oooo00000000000000000P3oool00`000000
oooo0?ooo`3o0?ooob`0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`030?ooo`800000
0P3oool5000000030?ooo`000000000000L0000000@0oooo0000003oool00000103oool00`000000
oooo0?ooo`3o0?ooobd0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`030?ooo`L00000
00<0oooo0000000000003`0000000`3oool000000?ooo`3o0?ooobl0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`040?ooo`D0000000<0oooo0000000000001`0000000`3oool000000000
000300000080oooo00<000000?ooo`000000o`3oool`0?ooo`4000000@3oool001H0oooo00<00000
0?ooo`3oool01P3oool2000000030?ooo`000000oooo00@0000000<0oooo0000000000000P000000
103oool000000000000000020?ooo`030000003oool000000?l0oooo<@3oool100000040oooo000F
0?ooo`030000003oool0oooo00H0oooo4P0000020?ooo`030000003oool000000?l0oooo<@3oool1
00000040oooo000F0?ooo`030000003oool0oooo00D0oooo3@0000000`3oool00000000000020000
0080oooo1@00003o0?oooc00oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool000000?ooo`<0000000<0oooo0000000000000P0000000`3oool00000000000030000
00030?ooo`000000000000<0000000<0oooo0000003oool0o`3oool_0?ooo`4000000@3oool001H0
oooo00<000000?ooo`3oool01@3oool4000000030?ooo`00000000000080000000<0oooo0000003o
ool00`0000030?ooo`<000000`3oool00`000000oooo0000003o0?ooobh0oooo0@0000010?ooo`00
5P3oool00`000000oooo0?ooo`060?ooo`T0000000<0oooo0000000000000P0000020?ooo`800000
00H0oooo0000003oool0oooo0000003oool200000?l0oooo;P3oool100000040oooo000F0?ooo`03
0000003oool0oooo00H0oooo200000000`3oool000000000000200000080oooo100000030?ooo`05
0000003oool000000?ooo`000000o`3oool]0?ooo`4000000@3oool001H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo00000003000000030?ooo`000000000000<000000P3oool300000003
0?ooo`00000000000080000000@0oooo0000003oool00000o`3oool^0?ooo`4000000@3oool001H0
oooo00<000000?ooo`3oool0103oool200000080oooo0`0000020?ooo`@000000P3oool3000000<0
oooo00H000000?ooo`00000000000?ooo`00000?0?ooo`030000003oool0oooo0?l0oooo7@3oool1
00000040oooo000F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000040?oo
o`L0000000L0oooo000000000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo0`0000001`3oool000000?ooo`000000oooo0000003oool00P0000000`3oool0
00000?ooo`020?ooo`030000003oool0oooo0?l0oooo;P3oool100000040oooo000F0?ooo`030000
003oool0oooo00<0oooo1@0000030?ooo`@0000000<0oooo0000003oool00P0000030?ooo`800000
103oool00`000000oooo0?ooo`3o0?ooobh0oooo0@0000010?ooo`005P3oool00`000000oooo0?oo
o`070?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool3000000040?ooo`0000000000
0?ooo`8000000`3oool200000?l0oooo<@3oool100000040oooo000F0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`0300000080oooo0`0000030?oo
o`030000003oool0oooo00`0oooo0P00003o0?ooob<0oooo0@0000010?ooo`005P3oool00`000000
oooo0?ooo`080?ooo`<000000`3oool020000000oooo000000000000oooo0000003oool00000103o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo8P3oool100000040oooo000F
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0000003o
ool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0o`3ooolb0?ooo`4000000@3o
ool001H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000P3oool2000000h0oooo00<000000?ooo`3oool0o`3ooolT
0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool01`3oool02P000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool300000080oooo00<000000?ooo`3oool0o`3ooole0?ooo`40
00000@3oool001H0oooo00<000000?ooo`3oool01`3oool01P000000oooo0?ooo`3oool000000?oo
o`D000000`3oool00`000000oooo0?ooo`3o0?ooocH0oooo0@0000010?ooo`005P3oool00`000000
oooo0?ooo`070?ooo`040000003oool0000000000080oooo0P0000000`3oool000000?ooo`030?oo
o`030000003oool0oooo0?l0oooo=P3oool100000040oooo000F0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000?l0oooo>@3oool10000
0040oooo000F0?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000080?oo
o`800000o`3oool`0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool03P3oool01@000000
oooo0?ooo`3oool000000?l0oooo>`3oool100000040oooo000F0?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`3o0?oooc40oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`80
0000o`3ooolc0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool03`3oool200000?l0oooo
?@3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooom30?ooo`4000000@3oool001H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oood<0oooo0@0000010?ooo`005P3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o
0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`005P3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooodh0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0<0?ooo`<00000o`3o
oolo0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o
0?oooch0oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0oooo@03oool100000040oooo000F0?ooo`030000003oool0oooo00X0oooo0P00003o0?oood80
oooo0@0000010?ooo`005P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
@03oool100000040oooo000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3o
oom30?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0203oool200000?l0ooooA03oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo00050?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool000@0oooo1P00000<
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo00050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`4000000@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo00090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool001H0oooo00<00000
0?ooo`3oool0o`3ooom>0?ooo`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?oo
o`4000000@3oool001H0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`4000000@3oool000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`000`3oool8000000/0oooo00<00000
0?ooo`3oool0o`3ooom>0?ooo`4000000@3oool000X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo0@0000010?ooo`002P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0oooo
CP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F
0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo
0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040
oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003o
ool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool1
00000040oooo000F0?ooo`030000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooo`03
0000003oool0oooo0?l0ooooCP3oool100000040oooo000F0?ooool00000DP0000010?ooo`00o`3o
oomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-10.1749, -9.79282, 0.49017, \
0.49017}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  ContourGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Perform 2D Fourier transform and re-order data so that w1=w3=0 is centerd in \
the middle. Frequency axis w1 is inverted.\
\>", "Text"],

Cell[BoxData[{
    \(\(spectrum2Dr = Fourier[Rr];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dr = 
        Reverse[Drop[RotateRight[spectrum2Dr, {nt/2, nt/2}], 1, 
            1]];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = Fourier[Rnr];\)\), "\[IndentingNewLine]", 
    \(\(spectrum2Dnr = 
        Drop[RotateRight[spectrum2Dnr, {nt/2, nt/2}], 1, 
          1];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(spectrum2Dabs = Re[spectrum2Dr + spectrum2Dnr];\)\)}], "Input"],

Cell["Plot purely absorptive spectrum", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{\(ticks = 
        Table[{\ \((w - woff)\)* .188*nt*\(dt/2\)/Pi + nt/2, w}, {w, 1800, 
            2000, 50}];\), "\[IndentingNewLine]", \(max = 
        Max[{Max[
              spectrum2Dabs], \(-Min[
                spectrum2Dabs]\)}];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"p1", "=", 
        RowBox[{"ListContourPlot", "[", 
          RowBox[{
          "spectrum2Dabs", ",", " ", \(PlotRange \[Rule] {0, max}\), 
            ",", \(ContourShading \[Rule] False\), 
            ",", \(Contours \[Rule] 20\), ",", \(Ticks \[Rule] None\), 
            ",", \(ContourStyle \[Rule] {RGBColor[0, 0, 1]}\), ",", 
            StyleBox[\(DisplayFunction -> Identity\),
              "MR"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"p2", "=", 
        RowBox[{"ListContourPlot", "[", 
          RowBox[{
          "spectrum2Dabs", ",", " ", \(PlotRange \[Rule] {\(-max\), 0}\), 
            ",", \(ContourShading \[Rule] False\), 
            ",", \(Contours \[Rule] 20\), ",", \(Ticks \[Rule] None\), 
            ",", \(ContourStyle \[Rule] {RGBColor[1, 0, 0]}\), ",", 
            StyleBox[\(DisplayFunction -> Identity\),
              "MR"]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(Show[{p1, p2}, 
        FrameTicks \[Rule] {ticks, ticks, None, None}, 
        PlotRange \[Rule] {{1, nt - 1}, {1, nt - 1}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00793651 0.00793651 -0.00793651 0.00793651 [
[.00606 -0.0125 -12 -9 ]
[.00606 -0.0125 12 0 ]
[.38601 -0.0125 -12 -9 ]
[.38601 -0.0125 12 0 ]
[.76597 -0.0125 -12 -9 ]
[.76597 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00606 -24 -4.5 ]
[-0.0125 .00606 0 4.5 ]
[-0.0125 .38601 -24 -4.5 ]
[-0.0125 .38601 0 4.5 ]
[-0.0125 .76597 -24 -4.5 ]
[-0.0125 .76597 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00606 0 m
.00606 .00625 L
s
[(1850)] .00606 -0.0125 0 1 Mshowa
.38601 0 m
.38601 .00625 L
s
[(1900)] .38601 -0.0125 0 1 Mshowa
.76597 0 m
.76597 .00625 L
s
[(1950)] .76597 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .00606 m
.00625 .00606 L
s
[(1850)] -0.0125 .00606 1 0 Mshowa
0 .38601 m
.00625 .38601 L
s
[(1900)] -0.0125 .38601 1 0 Mshowa
0 .76597 m
.00625 .76597 L
s
[(1950)] -0.0125 .76597 1 0 Mshowa
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.22222 .30134 m
.22253 .30159 L
.22222 .30471 L
.2205 .30159 L
.22222 .30134 L
s
.22222 .29844 m
.22559 .30159 L
.22222 .30851 L
.21654 .30159 L
.22222 .29844 L
s
.22222 .2964 m
.22759 .30159 L
.2245 .30952 L
.22222 .31167 L
.21779 .30952 L
.21431 .30159 L
.22222 .2964 L
s
.21429 .29831 m
.22222 .29464 L
.22927 .30159 L
.2269 .30952 L
.22222 .31429 L
.21506 .30952 L
.21429 .30857 L
.21183 .30159 L
.21429 .29831 L
s
.22222 .29297 m
.22413 .29365 L
.23016 .29975 L
.23087 .30159 L
.23016 .30677 L
.22878 .30952 L
.22222 .31588 L
.21429 .31206 L
.2125 .30952 L
.20998 .30159 L
.21429 .29608 L
.21826 .29365 L
.22222 .29297 L
s
.22222 .29133 m
.22698 .29365 L
.23016 .29694 L
.23242 .30159 L
.23048 .30952 L
.23016 .31034 L
.22222 .31677 L
.21429 .31471 L
.21037 .30952 L
.20859 .30159 L
.21429 .29415 L
.21498 .29365 L
.22222 .29133 L
s
.21429 .29228 m
.22222 .28974 L
.22913 .29365 L
.23016 .29473 L
.23384 .30159 L
.23216 .30952 L
.23016 .31384 L
.22222 .31729 L
.21429 .31621 L
.2088 .30952 L
.20747 .30159 L
.21203 .29365 L
.21429 .29228 L
s
.21429 .29048 m
.22222 .28816 L
.23016 .29267 L
.23111 .29365 L
.23517 .30159 L
.23369 .30952 L
.23016 .31583 L
.22521 .31746 L
.22222 .31842 L
.21697 .31746 L
.21429 .31701 L
.20757 .30952 L
.20643 .30159 L
.20976 .29365 L
.21429 .29048 L
s
.21429 .28872 m
.22222 .28651 L
.23016 .29068 L
.23298 .29365 L
.23648 .30159 L
.23512 .30952 L
.23016 .31686 L
.22807 .31746 L
.22222 .32001 L
.21429 .31778 L
.21355 .31746 L
.20647 .30952 L
.20635 .30915 L
.20489 .30159 L
.20635 .2975 L
.20814 .29365 L
.21429 .28872 L
s
.22222 .28476 m
.22536 .28571 L
.23016 .28875 L
.23468 .29365 L
.2378 .30159 L
.23651 .30952 L
.23038 .31746 L
.23016 .31763 L
.22222 .32174 L
.21429 .31952 L
.21045 .31746 L
.20635 .31357 L
.20485 .30952 L
.2032 .30159 L
.20635 .2946 L
.20682 .29365 L
.21429 .28691 L
.21681 .28571 L
.22222 .28476 L
s
.65873 .74116 m
.66667 .74328 L
.668 .74603 L
.66667 .75102 L
.65873 .75341 L
.65492 .74603 L
.65873 .74116 L
s
.21429 .28497 m
.22222 .28281 L
.22877 .28571 L
.23016 .28676 L
.23631 .29365 L
.2381 .29735 L
.23929 .30159 L
.2381 .30903 L
.23792 .30952 L
.23262 .31746 L
.23016 .31953 L
.22222 .32363 L
.21429 .3214 L
.2084 .31746 L
.20635 .31597 L
.20303 .30952 L
.20132 .30159 L
.20512 .29365 L
.20635 .29196 L
.21255 .28571 L
.21429 .28497 L
s
.65873 .73775 m
.6645 .7381 L
.66667 .73918 L
.67088 .74603 L
.66809 .75397 L
.66667 .75598 L
.65873 .75781 L
.65482 .75397 L
.65189 .74603 L
.65804 .7381 L
.65873 .73775 L
s
.21429 .28282 m
.22222 .28059 L
.23016 .28462 L
.23161 .28571 L
.23795 .29365 L
.2381 .29392 L
.24089 .30159 L
.23953 .30952 L
.2381 .31389 L
.23461 .31746 L
.23016 .3216 L
.22363 .3254 L
.22222 .32572 L
.21885 .3254 L
.21429 .32349 L
.20686 .31746 L
.20635 .31714 L
.201 .30952 L
.1992 .30159 L
.20302 .29365 L
.20635 .28946 L
.2093 .28571 L
.21429 .28282 L
s
.65873 .73462 m
.66667 .73577 L
.66937 .7381 L
.67341 .74603 L
.67117 .75397 L
.66667 .75945 L
.65873 .76036 L
.65158 .75397 L
.65079 .75263 L
.64907 .74603 L
.65079 .74154 L
.65349 .7381 L
.65873 .73462 L
s
.21429 .28032 m
.22222 .27801 L
.23016 .28218 L
.23418 .28571 L
.2381 .29075 L
.23984 .29365 L
.2426 .30159 L
.24125 .30952 L
.2381 .31632 L
.23649 .31746 L
.23016 .32393 L
.22826 .3254 L
.22222 .32797 L
.21429 .32581 L
.21325 .3254 L
.20635 .31903 L
.20486 .31746 L
.19869 .30952 L
.19841 .30895 L
.19694 .30159 L
.19841 .29712 L
.20063 .29365 L
.20635 .28696 L
.20722 .28571 L
.21429 .28032 L
s
.65079 .73709 m
.65873 .7317 L
.66667 .73268 L
.67261 .7381 L
.6746 .74154 L
.67592 .74603 L
.6746 .75236 L
.67387 .75397 L
.66667 .76146 L
.66468 .7619 L
.65873 .76219 L
.65791 .7619 L
.65079 .75788 L
.64854 .75397 L
.64624 .74603 L
.64999 .7381 L
.65079 .73709 L
s
.21429 .27741 m
.22222 .27517 L
.22821 .27778 L
.23016 .2793 L
.23652 .28571 L
.2381 .28778 L
.24188 .29365 L
.24444 .30159 L
.2431 .30952 L
.23843 .31746 L
.2381 .3179 L
.23164 .3254 L
.23016 .32651 L
.22222 .33069 L
.21429 .32837 L
.20923 .3254 L
.20635 .32163 L
.20237 .31746 L
.19841 .31442 L
.19622 .30952 L
.19427 .30159 L
.19791 .29365 L
.19841 .29285 L
.20486 .28571 L
.20635 .28422 L
.21338 .27778 L
.21429 .27741 L
s
.65873 .72852 m
.66667 .72948 L
.6679 .73016 L
.6746 .73642 L
.67566 .7381 L
.67857 .74603 L
.67661 .75397 L
.6746 .75812 L
.67011 .7619 L
.66667 .76418 L
.65873 .76516 L
.6527 .7619 L
.65079 .76085 L
.64545 .75397 L
.64315 .74603 L
.64653 .7381 L
.65079 .73322 L
.65503 .73016 L
.65873 .72852 L
s
.21429 .27406 m
.22222 .27163 L
.23016 .27597 L
.23239 .27778 L
.2381 .28457 L
.23901 .28571 L
.24412 .29365 L
.24603 .29905 L
.24644 .30159 L
.24603 .30602 L
.2451 .30952 L
.24068 .31746 L
.2381 .32087 L
.23463 .3254 L
.23016 .32952 L
.22434 .33333 L
.22222 .33394 L
.21797 .33333 L
.21429 .33153 L
.20683 .3254 L
.20635 .32465 L
.19945 .31746 L
.19841 .3169 L
.19318 .30952 L
.19095 .30159 L
.1948 .29365 L
.19841 .28902 L
.20171 .28571 L
.20635 .28096 L
.20864 .27778 L
.21429 .27406 L
s
.65079 .72938 m
.65873 .7246 L
.66667 .7256 L
.67273 .73016 L
.6746 .73206 L
.67892 .7381 L
.68145 .74603 L
.67953 .75397 L
.6746 .76133 L
.67385 .7619 L
.66667 .76769 L
.65873 .76871 L
.65079 .76385 L
.64857 .7619 L
.64286 .75587 L
.64201 .75397 L
.63963 .74603 L
.64273 .7381 L
.64286 .73787 L
.64985 .73016 L
.65079 .72938 L
s
.21429 .26973 m
.22222 .26726 L
.22779 .26984 L
.23016 .2718 L
.23598 .27778 L
.2381 .28068 L
.24191 .28571 L
.24603 .29235 L
.24658 .29365 L
.24863 .30159 L
.2473 .30952 L
.24603 .3136 L
.24314 .31746 L
.2381 .3244 L
.23739 .3254 L
.23017 .33333 L
.23016 .33334 L
.22222 .33785 L
.21429 .33533 L
.21065 .33333 L
.20635 .3281 L
.20369 .3254 L
.19841 .3199 L
.19614 .31746 L
.19048 .31185 L
.18945 .30952 L
.18704 .30159 L
.19048 .29397 L
.19072 .29365 L
.19788 .28571 L
.19841 .28515 L
.20554 .27778 L
.20635 .27696 L
.21403 .26984 L
.21429 .26973 L
s
.65873 .71967 m
.66667 .72067 L
.66921 .72222 L
.6746 .72731 L
.67718 .73016 L
.68254 .73806 L
.68256 .7381 L
.68472 .74603 L
.68278 .75397 L
.68254 .75465 L
.6776 .7619 L
.6746 .76527 L
.66994 .76984 L
.66667 .77192 L
.65873 .77294 L
.65289 .76984 L
.65079 .76809 L
.64431 .7619 L
.64286 .76078 L
.6378 .75397 L
.63492 .74605 L
.63492 .74603 L
.63492 .74601 L
.63812 .7381 L
.64286 .73205 L
.6448 .73016 L
.65079 .72454 L
.65367 .72222 L
.65873 .71967 L
s
.22222 .26141 m
.22383 .2619 L
.23016 .26639 L
.23369 .26984 L
.2381 .27575 L
.23968 .27778 L
.24521 .28571 L
.24603 .28698 L
.24934 .29365 L
.25098 .30159 L
.24971 .30952 L
.24603 .31729 L
.24587 .31746 L
.24055 .3254 L
.2381 .32858 L
.23471 .33333 L
.23016 .33805 L
.22629 .34127 L
.22222 .34303 L
.21571 .34127 L
.21429 .34033 L
.20676 .33333 L
.20635 .33264 L
.19961 .3254 L
.19841 .32415 L
.19186 .31746 L
.19048 .31661 L
.18469 .30952 L
.18254 .30567 L
.18166 .30159 L
.18254 .29828 L
.18557 .29365 L
.19048 .28809 L
.19311 .28571 L
.19841 .28033 L
.20087 .27778 L
.20635 .27189 L
.20761 .26984 L
.21429 .26419 L
.21864 .2619 L
.22222 .26141 L
s
.12698 .73697 m
.13029 .7381 L
.13492 .74119 L
.13949 .74603 L
.14149 .75397 L
.13492 .75863 L
.12698 .76129 L
.11993 .75397 L
.11905 .75264 L
.11668 .74603 L
.11905 .74089 L
.1225 .7381 L
.12698 .73697 L
s
.65873 .71278 m
.66667 .71385 L
.66742 .71429 L
.6746 .72085 L
.67589 .72222 L
.68221 .73016 L
.68254 .73058 L
.68686 .7381 L
.68852 .74603 L
.68655 .75397 L
.68254 .76105 L
.68176 .7619 L
.6754 .76984 L
.6746 .77067 L
.66667 .77773 L
.66658 .77778 L
.65873 .77879 L
.65636 .77778 L
.65079 .7735 L
.64681 .76984 L
.64286 .7657 L
.6392 .7619 L
.63492 .75807 L
.63218 .75397 L
.6286 .74603 L
.63163 .7381 L
.63492 .73352 L
.6386 .73016 L
.64286 .72576 L
.64628 .72222 L
.65079 .71802 L
.65553 .71429 L
.65873 .71278 L
s
.57143 .2933 m
.57275 .29365 L
.57937 .29774 L
.58296 .30159 L
.58489 .30952 L
.57937 .31415 L
.57143 .31533 L
.56411 .30952 L
.56349 .30855 L
.56122 .30159 L
.56349 .29707 L
.56869 .29365 L
.57143 .2933 L
s
.22222 .25308 m
.22452 .25397 L
.23016 .25861 L
.23324 .2619 L
.2381 .26888 L
.2388 .26984 L
.24423 .27778 L
.24603 .28065 L
.24905 .28571 L
.25236 .29365 L
.25351 .30159 L
.2523 .30952 L
.24898 .31746 L
.24603 .32246 L
.24422 .3254 L
.23886 .33333 L
.2381 .33437 L
.23337 .34127 L
.23016 .34472 L
.22491 .34921 L
.22222 .35031 L
.21728 .34921 L
.21429 .34725 L
.20778 .34127 L
.20635 .33869 L
.20179 .33333 L
.19841 .32951 L
.19451 .3254 L
.19048 .32144 L
.18623 .31746 L
.18254 .31489 L
.17801 .30952 L
.1746 .30447 L
.1738 .30159 L
.1746 .2981 L
.17779 .29365 L
.18254 .28864 L
.18624 .28571 L
.19048 .28179 L
.19467 .27778 L
.19841 .27383 L
.202 .26984 L
.20635 .26472 L
.20796 .2619 L
.21429 .25617 L
.21781 .25397 L
.22222 .25308 L
s
.11905 .73008 m
.12698 .72863 L
.13076 .73016 L
.13492 .73293 L
.14074 .7381 L
.14286 .74073 L
.14663 .74603 L
.14836 .75397 L
.14423 .7619 L
.14286 .76345 L
.13492 .76877 L
.12698 .76819 L
.11905 .76236 L
.11854 .7619 L
.11153 .75397 L
.11111 .75328 L
.10832 .74603 L
.11071 .7381 L
.11111 .73729 L
.11877 .73016 L
.11905 .73008 L
s
.65873 .70168 m
.66667 .70296 L
.67072 .70635 L
.6746 .71087 L
.67739 .71429 L
.68254 .72116 L
.68333 .72222 L
.68858 .73016 L
.69048 .73304 L
.69214 .7381 L
.69303 .74603 L
.69101 .75397 L
.69048 .7554 L
.68676 .7619 L
.68254 .76803 L
.68128 .76984 L
.67523 .77778 L
.6746 .7785 L
.66777 .78571 L
.66667 .78647 L
.65873 .78772 L
.65515 .78571 L
.65079 .78169 L
.64699 .77778 L
.64286 .77306 L
.63983 .76984 L
.63492 .76487 L
.63184 .7619 L
.62698 .75789 L
.62346 .75397 L
.61905 .74875 L
.61784 .74603 L
.61905 .73949 L
.62009 .7381 L
.62698 .73107 L
.62837 .73016 L
.63492 .72417 L
.63699 .72222 L
.64286 .71616 L
.64455 .71429 L
.65079 .70763 L
.65206 .70635 L
.65873 .70168 L
s
.13492 .29849 m
.13774 .30159 L
.13492 .30318 L
.1284 .30159 L
.13492 .29849 L
s
.57143 .2849 m
.57367 .28571 L
.57937 .28937 L
.58428 .29365 L
.5873 .29729 L
.59031 .30159 L
.59235 .30952 L
.58858 .31746 L
.5873 .319 L
.57937 .32457 L
.57143 .32417 L
.56349 .31832 L
.56255 .31746 L
.55586 .30952 L
.55556 .30899 L
.55305 .30159 L
.55556 .29389 L
.55567 .29365 L
.56349 .28625 L
.56473 .28571 L
.57143 .2849 L
s
.21429 .24291 m
.22222 .23921 L
.23016 .24577 L
.2304 .24603 L
.2359 .25397 L
.2381 .25787 L
.24059 .2619 L
.24538 .26984 L
.24603 .27098 L
.24988 .27778 L
.25346 .28571 L
.25397 .28691 L
.25571 .29365 L
.25628 .30159 L
.25512 .30952 L
.25397 .31386 L
.25243 .31746 L
.24857 .3254 L
.24603 .32976 L
.24402 .33333 L
.23928 .34127 L
.2381 .34316 L
.23466 .34921 L
.23016 .35535 L
.2287 .35714 L
.22222 .36197 L
.21429 .35835 L
.21254 .35714 L
.20679 .34921 L
.20635 .34827 L
.20124 .34127 L
.19841 .33766 L
.19478 .33333 L
.19048 .32871 L
.18703 .3254 L
.18254 .32141 L
.17761 .31746 L
.1746 .31561 L
.16667 .3096 L
.16661 .30952 L
.15873 .30339 L
.15671 .30159 L
.15873 .29586 L
.1622 .29365 L
.16667 .28942 L
.17384 .28571 L
.1746 .28512 L
.18254 .27928 L
.18441 .27778 L
.19048 .27224 L
Mistroke
.19288 .26984 L
.19841 .26348 L
.1997 .2619 L
.20566 .25397 L
.20635 .253 L
.21052 .24603 L
.21429 .24291 L
Mfstroke
.11905 .71377 m
.12698 .71419 L
.12715 .71429 L
.13492 .72116 L
.13601 .72222 L
.14286 .72983 L
.14318 .73016 L
.15079 .73766 L
.15126 .7381 L
.15873 .74479 L
.15961 .74603 L
.16454 .75397 L
.16278 .7619 L
.15873 .7678 L
.15644 .76984 L
.15079 .77561 L
.14864 .77778 L
.14286 .78274 L
.1382 .78571 L
.13492 .7866 L
.13073 .78571 L
.12698 .78357 L
.1212 .77778 L
.11905 .77519 L
.11434 .76984 L
.11111 .7663 L
.1068 .7619 L
.10317 .75874 L
.09877 .75397 L
.09524 .74945 L
.09362 .74603 L
.0948 .7381 L
.09524 .73628 L
.10066 .73016 L
.10317 .72735 L
.1081 .72222 L
.11111 .71941 L
.11782 .71429 L
.11905 .71377 L
s
.65873 .67658 m
.66667 .67831 L
.67043 .68254 L
.6746 .68887 L
.67562 .69048 L
.68044 .69841 L
.68254 .70193 L
.68525 .70635 L
.68996 .71429 L
.69048 .71522 L
.69416 .72222 L
.69713 .73016 L
.69841 .73672 L
.69853 .7381 L
.69841 .74428 L
.69824 .74603 L
.69635 .75397 L
.69306 .7619 L
.69048 .76673 L
.68883 .76984 L
.68421 .77778 L
.68254 .78048 L
.67951 .78571 L
.67471 .79365 L
.6746 .79381 L
.66932 .80159 L
.66667 .80436 L
.65873 .8061 L
.65353 .80159 L
.65079 .79806 L
.64755 .79365 L
.64286 .78687 L
.64202 .78571 L
.63572 .77778 L
.63492 .77686 L
.6281 .76984 L
.62698 .76881 L
.61905 .76252 L
.61819 .7619 L
.61111 .75794 L
.60317 .75488 L
.59524 .75402 L
.5873 .75567 L
.57937 .75959 L
.57513 .7619 L
.57143 .76378 L
.56349 .76464 L
.55833 .7619 L
.55556 .75899 L
.55334 .75397 L
Mistroke
.55556 .74637 L
.55575 .74603 L
.56269 .7381 L
.56349 .73722 L
.57013 .73016 L
.57143 .72913 L
.57937 .72356 L
.5873 .72267 L
.59524 .72372 L
.60317 .72381 L
.61043 .72222 L
.61111 .72199 L
.61905 .71835 L
.62539 .71429 L
.62698 .71285 L
.63409 .70635 L
.63492 .70537 L
.64091 .69841 L
.64286 .6957 L
.64657 .69048 L
.65079 .68462 L
.65236 .68254 L
.65873 .67658 L
Mfstroke
.55556 .27599 m
.56349 .27028 L
.57143 .27072 L
.57937 .27758 L
.57957 .27778 L
.58683 .28571 L
.5873 .28625 L
.59475 .29365 L
.59524 .29394 L
.60305 .30159 L
.60317 .30173 L
.60823 .30952 L
.60702 .31746 L
.60317 .32373 L
.60108 .3254 L
.59524 .33155 L
.59351 .33333 L
.5873 .33884 L
.58387 .34127 L
.57937 .3428 L
.57379 .34127 L
.57143 .33976 L
.56521 .33333 L
.56349 .33123 L
.55847 .3254 L
.55556 .32211 L
.55116 .31746 L
.54762 .31428 L
.54367 .30952 L
.53968 .30305 L
.53922 .30159 L
.53968 .2962 L
.54069 .29365 L
.54634 .28571 L
.54762 .28421 L
.55364 .27778 L
.55556 .27599 L
s
.21429 .21256 m
.22222 .20736 L
.22881 .21429 L
.23016 .21656 L
.23333 .22222 L
.23686 .23016 L
.2381 .23313 L
.24036 .2381 L
.24401 .24603 L
.24603 .25042 L
.2477 .25397 L
.25123 .2619 L
.25397 .26888 L
.25434 .26984 L
.25686 .27778 L
.25854 .28571 L
.25932 .29365 L
.25919 .30159 L
.25816 .30952 L
.25628 .31746 L
.25397 .32448 L
.25366 .3254 L
.25055 .33333 L
.24706 .34127 L
.24603 .34344 L
.24346 .34921 L
.23987 .35714 L
.2381 .36103 L
.23644 .36508 L
.23283 .37302 L
.23016 .37767 L
.22816 .38095 L
.22222 .38687 L
.21429 .38185 L
.21331 .38095 L
.20816 .37302 L
.20635 .36799 L
.20483 .36508 L
.20042 .35714 L
.19841 .35381 L
.19555 .34921 L
.19048 .34225 L
.18971 .34127 L
.18257 .33333 L
.18254 .3333 L
.1746 .32626 L
.17344 .3254 L
.16667 .32086 L
.15932 .31746 L
.15873 .31729 L
Mistroke
.15079 .31549 L
.14286 .31598 L
.13836 .31746 L
.13492 .31887 L
.12698 .32299 L
.11905 .32401 L
.11111 .32004 L
.10838 .31746 L
.104 .30952 L
.1074 .30159 L
.11111 .29546 L
.11565 .29365 L
.11905 .29039 L
.12354 .28571 L
.12698 .28266 L
.1332 .27778 L
.13492 .27677 L
.14286 .27497 L
.15079 .27477 L
.15873 .27374 L
.16667 .27107 L
.16953 .26984 L
.1746 .26674 L
.18109 .2619 L
.18254 .2605 L
.18896 .25397 L
.19048 .25202 L
.19508 .24603 L
.19841 .24073 L
.20004 .2381 L
.20451 .23016 L
.20635 .22659 L
.20792 .22222 L
.21255 .21429 L
.21429 .21256 L
Mfstroke
1 0 0 r
.28571 .71391 m
.29365 .70739 L
.30159 .70713 L
.30911 .71429 L
.30952 .71478 L
.31552 .72222 L
.31746 .72482 L
.32213 .73016 L
.3254 .73349 L
.3299 .7381 L
.33333 .74153 L
.33672 .74603 L
.33841 .75397 L
.33438 .7619 L
.33333 .76337 L
.32769 .76984 L
.3254 .77233 L
.32035 .77778 L
.31746 .78018 L
.30952 .78428 L
.30159 .78062 L
.29713 .77778 L
.29365 .77178 L
.29193 .76984 L
.28571 .76296 L
.28465 .7619 L
.27778 .75538 L
.27636 .75397 L
.26984 .7471 L
.26905 .74603 L
.26708 .7381 L
.26984 .73179 L
.27108 .73016 L
.27778 .72228 L
.27784 .72222 L
.28533 .71429 L
.28571 .71391 L
s
.74603 .68199 m
.75397 .67931 L
.7582 .68254 L
.7619 .6872 L
.76432 .69048 L
.76976 .69841 L
.76984 .69854 L
.77558 .70635 L
.77778 .70908 L
.78228 .71429 L
.78571 .7179 L
.79019 .72222 L
.79365 .72537 L
.79919 .73016 L
.80159 .73188 L
.80767 .7381 L
.80952 .74063 L
.81122 .74603 L
.80952 .74995 L
.8061 .75397 L
.80159 .75817 L
.79582 .7619 L
.79365 .76347 L
.78571 .76982 L
.78569 .76984 L
.77778 .7773 L
.77732 .77778 L
.77061 .78571 L
.76984 .78679 L
.76505 .79365 L
.7619 .79893 L
.76054 .80159 L
.75598 .80952 L
.75397 .81228 L
.74979 .81746 L
.74603 .82021 L
.73919 .81746 L
.7381 .81637 L
.73233 .80952 L
.73016 .80482 L
.72818 .80159 L
.72347 .79365 L
.72222 .79149 L
.71884 .78571 L
.71462 .77778 L
.71429 .77706 L
.71119 .76984 L
.70909 .7619 L
.70859 .75397 L
.7098 .74603 L
Mistroke
.7127 .7381 L
.71429 .73504 L
.71692 .73016 L
.72185 .72222 L
.72222 .72168 L
.72683 .71429 L
.73016 .70869 L
.73147 .70635 L
.73586 .69841 L
.7381 .69439 L
.74026 .69048 L
.74556 .68254 L
.74603 .68199 L
Mfstroke
.7381 .26496 m
.74603 .26491 L
.75194 .26984 L
.75397 .27208 L
.75892 .27778 L
.7619 .28153 L
.76569 .28571 L
.76984 .28986 L
.77365 .29365 L
.77778 .29503 L
.78088 .30159 L
.7831 .30952 L
.77924 .31746 L
.77778 .3195 L
.77247 .3254 L
.76984 .3282 L
.76496 .33333 L
.7619 .33582 L
.75397 .33978 L
.74603 .33625 L
.74125 .33333 L
.7381 .32764 L
.73607 .3254 L
.73016 .31894 L
.72865 .31746 L
.72222 .31151 L
.72023 .30952 L
.71429 .30329 L
.71303 .30159 L
.71152 .29365 L
.71429 .2879 L
.71605 .28571 L
.72222 .27881 L
.72322 .27778 L
.73016 .2709 L
.73123 .26984 L
.7381 .26496 L
s
.30159 .21426 m
.30952 .21202 L
.31189 .21429 L
.31699 .22222 L
.31746 .2231 L
.32125 .23016 L
.3254 .23792 L
.32549 .2381 L
.33003 .24603 L
.33333 .25111 L
.33526 .25397 L
.34127 .26169 L
.34145 .2619 L
.34881 .26984 L
.34921 .27023 L
.35714 .27731 L
.35773 .27778 L
.36508 .28352 L
.36811 .28571 L
.37302 .28907 L
.37842 .29365 L
.38095 .29619 L
.38397 .30159 L
.38095 .30833 L
.37983 .30952 L
.37302 .31543 L
.36854 .31746 L
.36508 .31961 L
.35714 .32494 L
.3565 .3254 L
.34921 .33086 L
.34633 .33333 L
.34127 .33813 L
.33833 .34127 L
.33333 .34745 L
.33201 .34921 L
.32677 .35714 L
.3254 .35964 L
.32236 .36508 L
.3185 .37302 L
.31746 .37535 L
.31536 .38095 L
.31166 .38889 L
.30952 .39232 L
.30663 .39683 L
.30159 .40131 L
.29525 .39683 L
.29365 .39445 L
.29013 .38889 L
.28677 .38095 L
Mistroke
.28571 .37816 L
.28342 .37302 L
.27993 .36508 L
.27778 .36013 L
.27645 .35714 L
.27309 .34921 L
.27009 .34127 L
.26984 .34055 L
.26753 .33333 L
.26568 .3254 L
.26463 .31746 L
.26443 .30952 L
.26512 .30159 L
.2667 .29365 L
.26914 .28571 L
.26984 .28396 L
.27223 .27778 L
.27577 .26984 L
.27778 .26571 L
.27952 .2619 L
.28319 .25397 L
.28571 .24831 L
.28669 .24603 L
.29006 .2381 L
.29344 .23016 L
.29365 .22968 L
.297 .22222 L
.30157 .21429 L
.30159 .21426 L
Mfstroke
.29365 .7277 m
.30159 .72555 L
.30952 .72965 L
.3103 .73016 L
.31746 .73753 L
.31791 .7381 L
.32308 .74603 L
.32337 .75397 L
.31825 .7619 L
.31746 .76269 L
.30952 .76772 L
.30159 .76653 L
.29531 .7619 L
.29365 .76051 L
.28782 .75397 L
.28571 .7509 L
.28343 .74603 L
.28434 .7381 L
.28571 .73358 L
.28978 .73016 L
.29365 .7277 L
s
.74603 .70322 m
.75397 .70261 L
.75921 .70635 L
.7619 .70919 L
.76656 .71429 L
.76984 .71803 L
.77369 .72222 L
.77778 .72649 L
.78136 .73016 L
.78571 .73426 L
.78856 .7381 L
.79197 .74603 L
.78848 .75397 L
.78571 .7578 L
.78064 .7619 L
.77778 .76462 L
.77245 .76984 L
.76984 .77261 L
.76528 .77778 L
.7619 .78188 L
.75937 .78571 L
.75397 .79117 L
.75093 .79365 L
.74603 .79571 L
.7404 .79365 L
.7381 .7918 L
.73223 .78571 L
.73016 .78264 L
.72644 .77778 L
.72222 .7718 L
.72087 .76984 L
.71649 .7619 L
.71435 .75397 L
.71507 .74603 L
.71858 .7381 L
.72222 .73258 L
.72396 .73016 L
.72986 .72222 L
.73016 .72184 L
.73573 .71429 L
.7381 .71134 L
.74231 .70635 L
.74603 .70322 L
s
.7381 .28399 m
.74603 .2821 L
.75334 .28571 L
.75397 .28618 L
.76166 .29365 L
.7619 .294 L
.76704 .30159 L
.76769 .30952 L
.76275 .31746 L
.7619 .31833 L
.75397 .32343 L
.74603 .32242 L
.73925 .31746 L
.7381 .31656 L
.73177 .30952 L
.73016 .30712 L
.72763 .30159 L
.72894 .29365 L
.73016 .29046 L
.73482 .28571 L
.7381 .28399 L
s
.30159 .24211 m
.30952 .24165 L
.3143 .24603 L
.31746 .25018 L
.32025 .25397 L
.3254 .26105 L
.32603 .2619 L
.33245 .26984 L
.33333 .27085 L
.33991 .27778 L
.34127 .2791 L
.34853 .28571 L
.34921 .28627 L
.35712 .29365 L
.35714 .29368 L
.36185 .30159 L
.35876 .30952 L
.35714 .31215 L
.34999 .31746 L
.34921 .3181 L
.34127 .32473 L
.34051 .3254 L
.33333 .33231 L
.33237 .33333 L
.32569 .34127 L
.3254 .34167 L
.31993 .34921 L
.31746 .353 L
.31552 .35714 L
.30952 .36441 L
.30889 .36508 L
.30159 .36922 L
.29524 .36508 L
.29365 .36321 L
.28912 .35714 L
.28571 .35117 L
.2845 .34921 L
.27978 .34127 L
.27778 .33774 L
.27527 .33333 L
.27144 .3254 L
.26984 .32122 L
.26873 .31746 L
.26753 .30952 L
.26803 .30159 L
.26984 .29472 L
.27023 .29365 L
.27379 .28571 L
.27778 .27874 L
.27832 .27778 L
Mistroke
.28312 .26984 L
.28571 .26558 L
.28782 .2619 L
.29254 .25397 L
.29365 .25224 L
.29786 .24603 L
.30159 .24211 L
Mfstroke
.30159 .73478 m
.309 .7381 L
.30952 .7385 L
.31654 .74603 L
.31421 .75397 L
.30952 .76111 L
.30159 .75931 L
.2959 .75397 L
.29365 .7507 L
.29179 .74603 L
.29365 .7398 L
.29502 .7381 L
.30159 .73478 L
s
.74603 .71314 m
.75397 .71314 L
.75615 .71429 L
.7619 .71921 L
.76501 .72222 L
.76984 .7273 L
.7725 .73016 L
.77778 .73579 L
.77925 .7381 L
.78252 .74603 L
.77973 .75397 L
.77778 .75742 L
.77285 .7619 L
.76984 .76509 L
.7653 .76984 L
.7619 .77346 L
.75865 .77778 L
.75397 .78128 L
.74603 .78473 L
.7381 .78088 L
.73439 .77778 L
.73016 .77254 L
.72793 .76984 L
.72241 .7619 L
.72222 .76159 L
.71919 .75397 L
.71953 .74603 L
.72222 .73994 L
.72336 .7381 L
.72921 .73016 L
.73016 .72903 L
.73574 .72222 L
.7381 .71977 L
.74405 .71429 L
.74603 .71314 L
s
.74603 .29114 m
.75215 .29365 L
.75397 .29497 L
.76017 .30159 L
.75849 .30952 L
.75397 .31408 L
.74603 .31557 L
.73987 .30952 L
.7381 .30692 L
.73603 .30159 L
.7381 .29573 L
.74003 .29365 L
.74603 .29114 L
s
.30159 .25471 m
.30952 .25475 L
.31728 .2619 L
.31746 .26212 L
.32398 .26984 L
.3254 .27152 L
.331 .27778 L
.33333 .28021 L
.33884 .28571 L
.34127 .28792 L
.34657 .29365 L
.34921 .29722 L
.35094 .30159 L
.34921 .30823 L
.34841 .30952 L
.34127 .31724 L
.34082 .31746 L
.33333 .3245 L
.33241 .3254 L
.3254 .33289 L
.32501 .33333 L
.31846 .34127 L
.31746 .34255 L
.31312 .34921 L
.30952 .3518 L
.30159 .35533 L
.29365 .34991 L
.29292 .34921 L
.28682 .34127 L
.28571 .33955 L
.28142 .33333 L
.27778 .32761 L
.2764 .3254 L
.27248 .31746 L
.27048 .30952 L
.27079 .30159 L
.2734 .29365 L
.27778 .28583 L
.27785 .28571 L
.28314 .27778 L
.28571 .27414 L
.28857 .26984 L
.29365 .26285 L
.29436 .2619 L
.30159 .25471 L
s
.74603 .71948 m
.75397 .71977 L
.75816 .72222 L
.7619 .72557 L
.76656 .73016 L
.76984 .7335 L
.77317 .7381 L
.77649 .74603 L
.774 .75397 L
.76984 .76025 L
.76764 .7619 L
.7619 .76793 L
.76062 .76984 L
.75397 .77504 L
.74769 .77778 L
.74603 .77794 L
.74504 .77778 L
.7381 .7741 L
.73326 .76984 L
.73016 .76595 L
.72715 .7619 L
.72331 .75397 L
.72333 .74603 L
.72727 .7381 L
.73016 .73412 L
.73341 .73016 L
.7381 .72531 L
.74145 .72222 L
.74603 .71948 L
s
.29365 .26951 m
.30159 .26244 L
.30952 .26271 L
.31746 .26945 L
.31785 .26984 L
.32516 .27778 L
.3254 .27804 L
.33266 .28571 L
.33333 .28636 L
.33988 .29365 L
.34127 .29549 L
.34396 .30159 L
.34178 .30952 L
.34127 .31083 L
.33482 .31746 L
.33333 .31898 L
.32698 .3254 L
.3254 .32709 L
.31976 .33333 L
.31746 .33593 L
.31399 .34127 L
.30952 .3441 L
.30159 .34696 L
.29365 .34192 L
.29291 .34127 L
.28632 .33333 L
.28571 .33246 L
.2806 .3254 L
.27778 .32095 L
.27586 .31746 L
.27317 .30952 L
.27332 .30159 L
.2763 .29365 L
.27778 .29105 L
.28128 .28571 L
.28571 .27968 L
.28707 .27778 L
.29334 .26984 L
.29365 .26951 L
s
.7381 .72946 m
.74603 .72401 L
.75397 .72451 L
.76177 .73016 L
.7619 .73028 L
.76873 .7381 L
.76984 .73983 L
.77198 .74603 L
.76985 .75397 L
.76984 .754 L
.76352 .7619 L
.7619 .7636 L
.75549 .76984 L
.75397 .77051 L
.74603 .77296 L
.73887 .76984 L
.7381 .76924 L
.73106 .7619 L
.73016 .76062 L
.72678 .75397 L
.72657 .74603 L
.73016 .73868 L
.73055 .7381 L
.73729 .73016 L
.7381 .72946 L
s
.30159 .26793 m
.30952 .26831 L
.31212 .26984 L
.31746 .27469 L
.32056 .27778 L
.3254 .28292 L
.32801 .28571 L
.33333 .29133 L
.33501 .29365 L
.33897 .30159 L
.33692 .30952 L
.33333 .31578 L
.33044 .31746 L
.3254 .3228 L
.32293 .3254 L
.31746 .33122 L
.31649 .33333 L
.30952 .33869 L
.30159 .3412 L
.29365 .33631 L
.29048 .33333 L
.28571 .32732 L
.28418 .3254 L
.27888 .31746 L
.27778 .31541 L
.27568 .30952 L
.27567 .30159 L
.27778 .2958 L
.27891 .29365 L
.28426 .28571 L
.28571 .28389 L
.29049 .27778 L
.29365 .27438 L
.2984 .26984 L
.30159 .26793 L
s
.74603 .72768 m
.75397 .7283 L
.75726 .73016 L
.7619 .73415 L
.76501 .7381 L
.76847 .74603 L
.76634 .75397 L
.7619 .76071 L
.76078 .7619 L
.75397 .76684 L
.74603 .76921 L
.7381 .76524 L
.73447 .7619 L
.73016 .75496 L
.72979 .75397 L
.72939 .74603 L
.73016 .74381 L
.73341 .7381 L
.7381 .73286 L
.74136 .73016 L
.74603 .72768 L
s
.30159 .27207 m
.30952 .27256 L
.31663 .27778 L
.31746 .27862 L
.32443 .28571 L
.3254 .28669 L
.33124 .29365 L
.33333 .29678 L
.33509 .30159 L
.33333 .30946 L
.3333 .30952 L
.327 .31746 L
.3254 .31925 L
.31955 .3254 L
.31746 .32751 L
.31248 .33333 L
.30952 .33458 L
.30159 .33673 L
.29503 .33333 L
.29365 .33213 L
.28726 .3254 L
.28571 .32334 L
.28155 .31746 L
.27799 .30952 L
.27786 .30159 L
.28125 .29365 L
.28571 .28722 L
.28688 .28571 L
.29365 .278 L
.29386 .27778 L
.30159 .27207 L
s
.7381 .73597 m
.74603 .73064 L
.75397 .73138 L
.7618 .7381 L
.7619 .73823 L
.76542 .74603 L
.7634 .75397 L
.7619 .75738 L
.75774 .7619 L
.75397 .76374 L
.74603 .76596 L
.73823 .7619 L
.7381 .76179 L
.73239 .75397 L
.73185 .74603 L
.73616 .7381 L
.7381 .73597 L
s
.30159 .27543 m
.30952 .27596 L
.31272 .27778 L
.31746 .28194 L
.32131 .28571 L
.3254 .28999 L
.32812 .29365 L
.33197 .30159 L
.33017 .30952 L
.3254 .31692 L
.32418 .31746 L
.31746 .32453 L
.31715 .3254 L
.30952 .33125 L
.30159 .33331 L
.29365 .32866 L
.29008 .3254 L
.28571 .31992 L
.28396 .31746 L
.28008 .30952 L
.27984 .30159 L
.28336 .29365 L
.28571 .29019 L
.28924 .28571 L
.29365 .28114 L
.29739 .27778 L
.30159 .27543 L
s
.74603 .73327 m
.75397 .73416 L
.75879 .7381 L
.7619 .74305 L
.76277 .74603 L
.7619 .7514 L
.76142 .75397 L
.75397 .7615 L
.75218 .7619 L
.74603 .76315 L
.74252 .7619 L
.7381 .75856 L
.73488 .75397 L
.73414 .74603 L
.7381 .73913 L
.73902 .7381 L
.74603 .73327 L
s
.29365 .28373 m
.30159 .27814 L
.30952 .27875 L
.31746 .28469 L
.31856 .28571 L
.3254 .29338 L
.32557 .29365 L
.32926 .30159 L
.32759 .30952 L
.3254 .31486 L
.32165 .31746 L
.31746 .32186 L
.3156 .3254 L
.30952 .32843 L
.30159 .33031 L
.29365 .32586 L
.29306 .3254 L
.28614 .31746 L
.28571 .31685 L
.282 .30952 L
.28167 .30159 L
.2853 .29365 L
.28571 .29301 L
.29153 .28571 L
.29365 .28373 L
s
.74603 .73579 m
.75397 .73699 L
.75544 .7381 L
.76164 .74603 L
.75989 .75397 L
.75397 .75992 L
.74603 .76164 L
.7381 .75485 L
.73753 .75397 L
.73646 .74603 L
.7381 .74264 L
.74213 .7381 L
.74603 .73579 L
s
.30159 .28061 m
.30952 .28125 L
.31601 .28571 L
.31746 .28707 L
.32323 .29365 L
.3254 .29703 L
.32699 .30159 L
.32544 .30952 L
.3254 .30971 L
.31942 .31746 L
.31746 .31952 L
.31171 .3254 L
.30952 .32609 L
.30159 .32781 L
.29622 .3254 L
.29365 .32335 L
.2881 .31746 L
.28571 .31383 L
.28378 .30952 L
.28336 .30159 L
.28571 .29587 L
.28706 .29365 L
.29365 .28593 L
.29388 .28571 L
.30159 .28061 L
s
.74603 .73842 m
.75397 .74 L
.76035 .74603 L
.75653 .75397 L
.75397 .75656 L
.74603 .76038 L
.74033 .75397 L
.73889 .74603 L
.74603 .73842 L
s
.30159 .28274 m
.30952 .28341 L
.31341 .28571 L
.31746 .28928 L
.32113 .29365 L
.32502 .30159 L
.3234 .30952 L
.31746 .31744 L
.31744 .31746 L
.30952 .32398 L
.30581 .3254 L
.30159 .32569 L
.3005 .3254 L
.29365 .3211 L
.29001 .31746 L
.28571 .31029 L
.28543 .30952 L
.28494 .30159 L
.28571 .29921 L
.28872 .29365 L
.29365 .28798 L
.29626 .28571 L
.30159 .28274 L
s
.74603 .74119 m
.75397 .74371 L
.75649 .74603 L
.75397 .7515 L
.75159 .75397 L
.74603 .75658 L
.74382 .75397 L
.74149 .74603 L
.74603 .74119 L
s
.30159 .2846 m
.30952 .2853 L
.31039 .28571 L
.31746 .29144 L
.31921 .29365 L
.32314 .30159 L
.32157 .30952 L
.31746 .31676 L
.31694 .31746 L
.30952 .32203 L
.30159 .3237 L
.29365 .31904 L
.29196 .31746 L
.28695 .30952 L
.28641 .30159 L
.29033 .29365 L
.29365 .28988 L
.29904 .28571 L
.30159 .2846 L
s
.74603 .74487 m
.75107 .74603 L
.74603 .75099 L
.74496 .74603 L
.74603 .74487 L
s
.29365 .29173 m
.30159 .28628 L
.30952 .28704 L
.3174 .29365 L
.31746 .29372 L
.32143 .30159 L
.31989 .30952 L
.31746 .31535 L
.31575 .31746 L
.30952 .32026 L
.30159 .32189 L
.29402 .31746 L
.29365 .31711 L
.28838 .30952 L
.28778 .30159 L
.29195 .29365 L
.29365 .29173 L
s
.29365 .29362 m
.30159 .28787 L
.30952 .28867 L
.31568 .29365 L
.31746 .29605 L
.31986 .30159 L
.31833 .30952 L
.31746 .31233 L
.31303 .31746 L
.30952 .31863 L
.30159 .32023 L
.29613 .31746 L
.29365 .31525 L
.28979 .30952 L
.2891 .30159 L
.29362 .29365 L
.29365 .29362 L
s
.30159 .28938 m
.30952 .29025 L
.31391 .29365 L
.31746 .29885 L
.31838 .30159 L
.31746 .30807 L
.31745 .30952 L
.30952 .31741 L
.30871 .31746 L
.30159 .31867 L
.29862 .31746 L
.29365 .3133 L
.29121 .30952 L
.29041 .30159 L
.29365 .29551 L
.29528 .29365 L
.30159 .28938 L
s
.30159 .29085 m
.30952 .29183 L
.312 .29365 L
.31697 .30159 L
.31732 .30952 L
.30952 .31713 L
.30159 .31718 L
.29365 .31115 L
.29267 .30952 L
.29173 .30159 L
.29365 .2976 L
.29706 .29365 L
.30159 .29085 L
s
.30159 .29233 m
.30952 .29348 L
.30978 .29365 L
.3156 .30159 L
.31666 .30952 L
.30952 .31641 L
.30159 .31575 L
.29417 .30952 L
.29365 .30823 L
.2931 .30159 L
.29365 .30019 L
.29915 .29365 L
.30159 .29233 L
s
.30159 .29385 m
.30952 .29513 L
.31419 .30159 L
.31504 .30952 L
.30952 .31482 L
.30159 .31429 L
.29569 .30952 L
.29447 .30159 L
.30159 .29385 L
s
.30159 .29538 m
.30952 .2969 L
.31272 .30159 L
.31203 .30952 L
.30952 .31193 L
.30159 .31276 L
.29735 .30952 L
.29587 .30159 L
.30159 .29538 L
s
.30159 .29703 m
.30952 .299 L
.31112 .30159 L
.30952 .30841 L
.30844 .30952 L
.30159 .31109 L
.29933 .30952 L
.2974 .30159 L
.30159 .29703 L
s
.30159 .29894 m
.3092 .30159 L
.30159 .30908 L
.29917 .30159 L
.30159 .29894 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`005P3oool5
000000<0oooo100000040?ooo`@00000103oool4000005l0oooo1@0000020?ooo`@000001@3oool4
000000@0oooo1000001O0?ooo`D000000P3oool4000000D0oooo100000040?ooo`@00000@03oool0
01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03d0oooo000H0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo03d0oooo000H0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?ooo`D000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`030?ooo`D000001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo03d0oooo000H0?ooo`030000003oool0oooo00<0oooo100000040?ooo`@000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool4000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0m0?ooo`00603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo000F0?ooo`<00000103oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo05`0oooo0`0000040?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo05`0oooo
0`0000040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool001P0oooo00<000000?ooo`3oool0
0`3oool4000000@0oooo1@0000030?ooo`@00000H@3oool00`000000oooo0?ooo`030?ooo`@00000
103oool4000000@0oooo1000001Q0?ooo`030000003oool0oooo00<0oooo100000040?ooo`D00000
0`3oool400000400oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo0005000000<0oooo100000040?ooo`@00000103oool4
00000?l0ooooC@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`030?ooool00000AP0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000NP3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo04T0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo0`00001j0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0B@3o
ool100000040oooo00020?ooo`030000003oool0oooo00<0oooo100000040?ooo`@000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool000<00000103oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0080oooo00<000000?ooo`3oool00`3oool4000000@0oooo1@0000030?ooo`@000001P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?oo
o`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`00
0000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`140?ooo`80003on`3oool100000040oooo
000R0?ooo`030000003oool0oooo0480oooo0P000?l20?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool0g@3oool100000040oooo000R0?ooo`030000003oool0oooo0480oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`80o`0000<0oooo0?l0003oool0g@3oool1
00000040oooo000R0?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0f`3oool10000
0040oooo000R0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0fP3oool100000040
oooo000R0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0fP3oool100000040oooo
000R0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0fP3oool100000040oooo000R
0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0f@3oool100000040oooo000R0?oo
o`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0f@3oool100000040oooo000R0?ooo`03
0000003oool0oooo03h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0f03oool100000040oooo000R0?ooo`030000
003oool0oooo03d0oooo0P000?l50?ooo`80003o1@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool0f03oool100000040oooo000R0?ooo`030000003o
ool0oooo03`0oooo00<0003o0?ooo`3oool00`3oool20000o`80oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo0`3o00050?ooo`030?l0003o
ool0oooo0=L0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool00P3o00030?ooo`80o`00103oool00`3o0000oooo0?ooo`3F
0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`0<0?ooo`040?l0003oool0
oooo0?l000H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3F0?ooo`4000000@3o
ool00280oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0:0?ooo`040?l0003o
ool0oooo0?l000L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3E0?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0003o0`3oool01@000?l0oooo0?ooo`3oool0003o00/0oooo00@0o`000?ooo`3oool0
o`000P3oool30?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0003G0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000
o`@0oooo0P000?l20?ooo`040000o`3oool0oooo0000o`X0oooo00D0o`000?ooo`3oool0o`000?oo
o`020?l000<0oooo0P3o00000`3oool0o`000?ooo`030?ooo`030?l0003oool0oooo0=@0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0g0?ooo`80003o103oool010000?l0oooo0?ooo`00
0?l30?ooo`80003o0P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00H0oooo
00H0o`000?ooo`3oool0o`000?ooo`3o00020?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3o0000103oool00`3o0000oooo0?ooo`3C0?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0=P3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0000o`3oool00P000?l20?oo
o`060000o`3oool0oooo0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0o`000080oooo00@0o`000?ooo`3o0000oooo0P3o00030?ooo`030?l0003oool0o`0000@0oooo
00<0o`000?ooo`3oool0O@3oool40?l00540oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`0e0?ooo`030000o`3oool0oooo00@0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`80
003o00@0oooo0000o`3oool0003o0P3oool010000?l0oooo0?ooo`000?l70?ooo`080?l0003oool0
o`000?ooo`3o0000oooo0?l0003oool50?l000050?ooo`3o0000oooo0?ooo`3o0000103oool00`3o
0000oooo0?ooo`1k0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0CP3oool10000
0040oooo000R0?ooo`030000003oool0oooo0380oooo0`000?l60?ooo`070000o`3oool0oooo0000
o`3oool0003o0?ooo`070000o`040?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`020?l000040?ooo`3o0000o`000?l000<0oooo00D0o`000?ooo`3o0000
oooo0?l000020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0@`3oool30000oc<0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`1=0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0<03oool20000o`P0oooo00@0003o0?ooo`3oool0003o0P3oool40000o`80
oooo0P000?l0203oool0003o0?ooo`000?l0oooo0000o`3oool0003o1@3oool00`3o0000oooo0?oo
o`020?l000040?ooo`3o0000o`000?ooo`@0o`0000H0oooo0?l0003o0000o`000?ooo`3o00020?oo
o`030?l0003oool0oooo0080oooo0P3o00110?ooo`80003o0`3oool20000obl0oooo0P3o00070?oo
o`030?l0003oool0oooo04d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`P0
003o203oool20000o`80oooo00<0003o0?ooo`000?l030000?l01P3oool0003o0?ooo`000?l0oooo
0000o`@0oooo00@0o`000?ooo`3o0000oooo2`3o00001@3oool0o`000?l0003oool0o`000080oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0l0?ooo`80003o1`3oool00`000?l0oooo
0?ooo`0[0?ooo`030?l0003oool0oooo00P0oooo0P3o001=0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0>0?ooo`050000o`3oool0oooo0000o`3oool0
0P000?l00`3oool0003o0000o`040000o`030?ooo`000?l0oooo00@0003o00@0oooo0000o`3oool0
003o0`3oool00`3o0000oooo0?ooo`040?l000030?ooo`3o0000oooo00@0o`0000<0oooo0?l0003o
00000P3o00020?ooo`030?l0003oool0o`0000H0oooo00<0o`000?ooo`3oool0>P3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`1;0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool09P3oool00`000?l0oooo
0?ooo`0=0?ooo`80003o0P3oool01P000?l0oooo0000o`3oool0003o0?ooo`d0003o0P3oool00`00
0?l0oooo0000o`020?ooo`040?l0003oool0o`000?ooo`80o`0000<0oooo0?l0003o0000303o0000
0`3oool0o`000?ooo`020?l000D0oooo00<0o`000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool00`3oool40?l000@0oooo00<0o`00
0?ooo`3oool0BP3oool100000040oooo000R0?ooo`030000003oool0oooo02D0oooo00<0003o0?oo
o`3oool03@3oool020000?l0oooo0?ooo`3oool0003o0?ooo`000?l0oooo4@000?l0103oool0003o
0?ooo`000?l20?ooo`80o`0000<0oooo0?l0003o00003`3o0000103oool0o`000?ooo`3o00020?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`030?oo
o`@0003o0`3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3oool0B@3oool100000040oooo000R0?ooo`03
0000003oool0oooo02@0oooo00<0003o0?ooo`3oool0303oool20000o`<0oooo00@0003o0?ooo`00
0?l0oooo40000?l01P3oool0003o0000o`000?l0oooo0000o`80oooo5@3o00000`3oool0o`000?l0
00030?ooo`030?l0003oool0oooo00<0oooo0P3o000f0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3oool0oooo0P3o00190?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`000?l00P3oool20000o`030?ooo`000?l0003o00h0003o00@0
oooo0000o`000?l0oooo0P3o00000`3oool0o`000?l000020?l000030?ooo`3o0000o`0000/0o`00
00D0oooo0?l0003o0000oooo0?l000030?ooo`80o`00103oool00`3o0000oooo0?ooo`0d0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o
02H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool00`3o0000oooo0?ooo`170?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool08@3oool20000o`d0oooo0P000?l40?ooo`030000o`3oool0oooo01T0003o00<0oooo0?l0
003o00005@3o0000103oool0o`000?ooo`3o00030?ooo`030?l0003oool0oooo00<0oooo0P3o000c
0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`000?l20?ooo`050000o`3o
ool0oooo0?ooo`000?l09@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0o`00
00<0oooo0?l0003o00000P3oool0103o0000oooo0?ooo`3oool20?l004L0oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080003o00<0oooo0000o`000?l0
5@000?l00`3oool0o`000?l0000C0?l000040?ooo`3o0000o`000?l00080oooo00@0o`000?ooo`3o
ool0o`001P3oool00`3o0000oooo0?ooo`0a0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool0
10000?l0oooo0?ooo`3oool20000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000D0oooo00@0o`000?ooo`3oool0
o`000`3oool00`3o0000oooo0?ooo`150?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
7`3oool00`000?l0oooo0?ooo`040?ooo`80003o00<0oooo0000o`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080003o00<0oooo0000o`000?l05@000?l00`3oool0o`00
0?l0000:0?l000030?ooo`3o0000o`0000P0o`0000<0oooo0?l0003o00000P3oool0103o0000oooo
0?ooo`3o00060?ooo`030?l0003oool0oooo0300oooo00D0003o0?ooo`3oool0oooo0000o`020?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0o`001P3oool0103o0000oooo0?ooo`3o
00030?ooo`030?l0003oool0oooo04@0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0O
0?ooo`030000o`3oool0oooo00D0oooo0P000?l70?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00P000?l00`3oool0003o0000o`060000o`030?ooo`000?l0003o00`0003o00<0oooo
0?l0003o00002P3o00000`3oool0o`000?l000080?l000050?ooo`3o0000o`000?ooo`3o00000`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0340oooo00D0003o0?ooo`3oool0oooo
0000o`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo
0?ooo`0Q0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`040?ooo`04
0?l0003oool0oooo0?l000<0oooo00<0o`000?ooo`3oool0A03oool100000040oooo000R0?ooo`03
0000003oool0oooo01h0oooo00<0003o0?ooo`3oool0403oool20000o`80oooo00D0003o0?ooo`3o
ool0003o0?ooo`0:0000o`030?ooo`000?l0003o00X0003o00<0oooo0?l0003o00005`3o0000103o
ool0o`000?ooo`3o00020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0<@3oool0
0`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`H0oooo00<0003o0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00001P3o
ool0103o0000oooo0?ooo`3o00040?ooo`030?l0003oool0oooo04<0oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0180oooo00@0003o0?ooo`3oool0003o
0P3ooolH0000o`030?ooo`3o0000o`0001T0o`0000D0oooo0?l0003oool0oooo0?l000060?ooo`03
0?l0003oool0oooo0380oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`0Q0?ooo`80o`000P3oool0103o
0000oooo0?ooo`3o00050?ooo`040?l0003oool0oooo0?l000@0oooo00<0o`000?ooo`3oool0@`3o
ool100000040oooo000R0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool04P3oool0
1@000?l0oooo0?ooo`000?l0oooo0080003o00<0oooo0000o`000?l04`000?l00`3oool0o`000?l0
000G0?l000030?ooo`3o0000o`000080oooo0P3o00050?ooo`030?l0003oool0oooo03@0oooo00D0
003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo00<0003o00<0oooo0000o`3oool0
103oool00`000?l0oooo0?ooo`0S0?ooo`040?l0003oool0oooo0?l00080oooo00<0o`000?ooo`3o
ool00P3o00020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0A03oool100000040
oooo000R0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool01`3oool80000o`<0oooo
0P000?l00`3oool0003o0000o`0D0000o`030?ooo`000?l0003o0080oooo5`3o0000103oool0o`00
0?ooo`3oool20?l000@0oooo0`3o000h0?ooo`80003o0P3oool00`000?l0oooo0?ooo`020000o`@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo0080
o`0000<0oooo0?l0003o00000`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo04@0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo
0P000?l80?ooo`80003o0`3oool00`000?l0oooo0000o`020?ooo`d0003o00P0oooo0000o`000?l0
003o0?ooo`000?l0oooo0000o`80oooo103o00000`3oool0o`000?l0000>0?l000030?ooo`3o0000
o`0000<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0j0?ooo`050000o`3oool0
oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02H0oooo00D0
o`000?ooo`3oool0oooo0?l000040?ooo`80o`00103oool00`3o0000oooo0?ooo`150?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool08P3oool60000o``0oooo00X0003o0?ooo`3oool0oooo
0000o`3oool0003o0?ooo`000?l0oooo2P000?l00`3oool0003o0?ooo`020000o`030?ooo`000?l0
003o00<0oooo0P3o00000`3oool0o`000?l000050?l000030?ooo`3o0000o`000080o`0000<0oooo
0?l0003o00000P3o00001@3oool0o`000?ooo`3o0000oooo0080o`00103oool00`3o0000oooo0?oo
o`0l0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo02P0oooo00@0o`000?ooo`3oool0oooo103o00050?ooo`030?l0003oool0oooo04H0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`060000o`3oool0oooo0?ooo`00
0?l0oooo0`000?l00`3oool0003o0000o`0=0000o`030?ooo`000?l0oooo0080oooo00D0o`000?oo
o`3o0000o`000?ooo`0@0?l000040?ooo`3o0000oooo0?l000@0oooo0P3o00100?ooo`040000o`3o
ool0oooo0?ooo`@0003o1P3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0A`3oool100000040oooo000R0?ooo`030000003oool0oooo03H0oooo00D0
003o0?ooo`3oool0oooo0000o`020?oooa00003o0P3oool020000?l0oooo0?ooo`3oool0o`000?oo
o`3o0000oooo0`3o00000`3oool0o`000?l000090?l000050?ooo`3o0000o`000?ooo`3o0000103o
ool00`3o0000oooo0?ooo`110?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo04L0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`0g0?ooo`80003o0P3oool00`000?l0oooo0000o`020?ooo`040000o`3oool0
003o0?ooo`<0003o00@0oooo0000o`000?l0oooo0P000?l00`3oool0003o0?ooo`030?ooo`030?l0
003oool0oooo0080o`0000@0oooo0?l0003o0000oooo1P3o00000`3oool0o`000?l000020?l00080
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`130?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo04P0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0h0?ooo`080000o`3oool0oooo0?ooo`00
0?l0oooo0000o`3oool60000o`030?ooo`000?l0oooo0080003o00@0oooo0000o`3oool0003o103o
ool01`3o0000oooo0?ooo`3o0000oooo0?l0003oool0103o00000`3oool0o`000?l000040?l00005
0?ooo`3o0000oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`140?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0;@3oool30?l000@0oooo0P3o001;0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool0>@3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`<0003o0P3oool6
0000o`040?ooo`000?l0oooo0000o`D0oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`030?l0
003oool0o`0000H0o`0000<0oooo0?l0003oool00P3o00020?ooo`80o`00B03oool00`000?l0oooo
0?ooo`030?ooo`80003o<`3oool0103o0000oooo0?l0003o001=0?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0>P3oool020000?l0oooo0?ooo`3oool0003o0?ooo`000?l0oooo0P000?l2
0?ooo`050000o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`040?ooo`050?l0003o
ool0oooo0?l0003oool00P3o0000103oool0o`000?ooo`3oool20?l00080oooo0P3o00000`3oool0
o`000?ooo`020?ooo`030?l0003oool0oooo04T0oooo0P000?l20?ooo`030000o`3oool0oooo03@0
oooo00<0o`000?ooo`3oool0C@3oool100000040oooo000R0?ooo`030000003oool0oooo03/0oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo0P000?l01`3oool0003o0?ooo`3oool0
003o0?ooo`000?l01`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3o0000
o`000P3oool20?l000030?ooo`3o0000o`0000<0oooo00<0o`000?ooo`3oool0C03oool20000ohL0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`000?l00`3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00H0
oooo00@0o`000?ooo`3oool0o`000P3oool0103o0000oooo0?ooo`3oool20?l00080oooo00<0o`00
0?ooo`3o00000`3oool00`3o0000oooo0?ooo`3E0?ooo`4000000@3oool00280oooo00<000000?oo
o`3oool0?03oool01@000?l0oooo0?ooo`3oool0003o0080oooo10000?l20?ooo`040000o`3oool0
oooo0000o`P0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?ooo`3F0?ooo`4000000@3oool00280oooo00<0
00000?ooo`3oool0?@3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00@0003o0?ooo`3oool0
003o2@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo0P3o00020?ooo`040?l0003oool0oooo
0?l00080oooo00<0o`000?ooo`3oool0e`3oool100000040oooo000R0?ooo`030000003oool0oooo
03h0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`040000o`3oool0oooo0000o`/0oooo00D0
o`000?ooo`3oool0oooo0?l000040?ooo`80o`000P3oool01@3o0000oooo0?ooo`3oool0o`000=T0
oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0n0?ooo`040000o`3oool0oooo0?ooo`80
003o0P3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00D0o`000?ooo`3oool0oooo0?l00006
0?ooo`050?l0003oool0oooo0?ooo`3o0000fP3oool100000040oooo000R0?ooo`030000003oool0
oooo03l0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0o`00f`3o
ool100000040oooo000R0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`050?l0003oool0
oooo0?ooo`3o0000f`3oool100000040oooo000R0?ooo`030000003oool0oooo0400oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo0`3o0003
0?ooo`030?l0003oool0oooo0=X0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`100?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo0=X0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`110?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0=X0oooo0@0000010?ooo`001@0000020?ooo`@000001@3oool4000000@0oooo
100000060?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0f`3oool100000040oooo
00020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo0=/0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04<0oooo0P000?l00`3oool0003o0?ooo`0B0?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool0f`3oool100000040oooo00020?ooo`030000003oool0oooo00<0
oooo1@0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`<00000A@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool0g03oool100000040oooo00020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1K0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool0g03oool100000040oooo00020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1L0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0g@3oool100000040oooo0003000000@0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1L0?ooo`050?l0003oool0oooo0?ooo`3o
0000h03oool100000040oooo00020?ooo`030000003oool0oooo00<0oooo100000040?ooo`@00000
103oool4000000H0oooo00<000000?ooo`3oool0G@3oool30?l00>40oooo0@0000010?ooo`008P3o
ool00`000000oooo0?ooo`1O0?ooo`030?l0003oool0oooo0=l0oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool0
0`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`00
8P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?oo
o`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000
oooo0?ooo`3o0?oood80oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3C0?ooo`030000
o`3oool0oooo06/0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3A0?ooo`80003o00<0
oooo0000o`000?l06`3oool00`3o0000oooo0?ooo`1=0?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0d03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01H0oooo0P3o0000
0`3oool0o`000?l0001=0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0d03oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`1:0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0c`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`1:0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0c`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`190?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0c@3oool20000o`X0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo04P0oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`3=0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo04L0oooo0@000001
0?ooo`008P3oool00`000000oooo0?ooo`3<0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`170?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0b`3oool00`000?l0oooo0?ooo`030?ooo`80003o00<0oooo0000o`000?l0103oool00`000?l0
oooo0?ooo`0>0?ooo`040?l0003oool0oooo0?ooo`80o`0000<0oooo0?l0003oool0103oool00`3o
0000oooo0?ooo`160?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0G03oool40?l006/0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0303oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`160?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0FP3oool20?l000@0oooo00<0o`000?ooo`3oool0IP3oool20000o`@0oooo00<0003o0?ooo`3o
ool01@3oool20000o`<0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?l000H0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`150?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool08`3oool40000oc80oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`1T0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@000?l30?ooo`050000
o`3oool0oooo0?ooo`000?l02`3oool01@3o0000oooo0?ooo`3o0000oooo00D0o`000P3oool20?l0
00<0oooo0P3o00150?ooo`4000000@3oool00280oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`1R0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0003o1@3oool20000
o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool0203oool01P3o0000oooo0?ooo`3o0000
oooo0?l000D0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo0480oooo
0@0000010?ooo`008P3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0600oooo0P00
0?l50?ooo`040000o`3oool0oooo0000o`<0oooo0`000?l20?ooo`030000o`3oool0003o0080oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`020?l00080oooo0`3o00020?ooo`040?l0
003oool0oooo0?l000@0oooo00<0o`000?ooo`3oool0@P3oool100000040oooo000R0?ooo`030000
003oool0oooo0200oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0
003oool0oooo00T0oooo00<0o`000?ooo`3oool0D`3oool<0000o`H0oooo00@0003o0?ooo`3oool0
003o0P3oool20000o`<0oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`030000o`3oool0oooo
00H0oooo00D0o`000?ooo`3oool0o`000?ooo`040?l00080oooo0P3o00001@3oool0o`000?ooo`3o
ool0o`0000@0oooo00<0o`000?ooo`3oool0@@3oool100000040oooo000R0?ooo`030000003oool0
oooo01h0oooo0P000?l:0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool01@3oool2
0?l000@0oooo00<0o`000?ooo`3oool0D03oool20000oa40oooo00@0003o0?ooo`3oool0003o0P3o
ool00`000?l0oooo0000o`030000o`060?ooo`000?l0003o0000o`3oool0003o0P3oool00`000?l0
oooo0?ooo`050?ooo`050?l0003oool0oooo0?l0003oool0103o00001`3oool0o`000?l0003o0000
oooo0?l0003oool00P3o00000`3oool0o`000?ooo`030?ooo`030?l0003oool0oooo0400oooo0@00
00010?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00<0oooo1@000?l3
0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool00`3oool30?l00080oooo0P3o0003
0?ooo`030?l0003oool0oooo04h0oooo00<0003o0?ooo`3oool0403oool01@000?l0oooo0?ooo`00
0?l0oooo00/0003o00@0oooo0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0100o`000P3oool00`3o0000oooo0?ooo`020?ooo`80o`00@03oool100000040oooo
000R0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`050000o`3oool0oooo0?ooo`000?l09`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l0001>0?ooo`030000o`3oool0oooo0100
oooo00L0003o0?ooo`3oool0003o0?ooo`000?l0oooo0080003o0P3oool80000o`80oooo00<0003o
0?ooo`000?l01@3oool01@3o0000oooo0?l0003o0000oooo00<0o`0000<0oooo0?l0003o00000P3o
00001@3oool0o`000?ooo`3o0000oooo0080o`000P3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo03d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o02D0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool01@3o0000oooo
0?ooo`3oool0o`0004d0oooo00<0003o0?ooo`3oool03`3oool01`000?l0oooo0?ooo`000?l0oooo
0000o`3oool00P000?l00`3oool0003o0000o`040000o`090?ooo`000?l0003o0?ooo`000?l0oooo
0000o`3oool0003o00D0oooo0P3o00000`3oool0o`000?ooo`0<0?l000040?ooo`3o0000oooo0?l0
0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0l0?ooo`4000000@3oool00280
oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
003o0P3oool01@000?l0oooo0?ooo`3oool0003o02@0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?l00080oooo0P3o00020?ooo`050?l0003oool0oooo0?ooo`3o0000BP3oool2
0000oa40oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`030?ooo`000?l0003o00X0003o
00D0oooo0000o`000?l0oooo0000o`040?ooo`050?l0003oool0o`000?l0003oool03P3o0000103o
ool0o`000?ooo`3o00020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0>`3oool1
00000040oooo000R0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0000o`040?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000D0oooo00<0o`000?ooo`3o0000103o
ool00`3o0000oooo0?ooo`160?ooo`030000o`3oool0oooo0140oooo00H0003o0?ooo`3oool0oooo
0000o`3oool60000o`030?ooo`000?l0oooo0080003o00D0oooo0000o`000?l0003o0?ooo`020000
o`030?ooo`000?l0oooo00<0oooo00<0o`000?ooo`3o00000P3o00000`3oool0o`000?l000060?l0
00050?ooo`3o0000o`000?l0003oool00P3o00001@3oool0o`000?ooo`3oool0o`0000D0oooo00<0
o`000?ooo`3oool0>`3oool100000040oooo000R0?ooo`030000003oool0oooo01/0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0003o00@0oooo00<0003o
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0o`0000H0oooo00@0o`00
0?ooo`3oool0o`000`3oool00`3o0000oooo0?ooo`160?ooo`030000o`3oool0oooo0100oooo00H0
003o0?ooo`3oool0oooo0000o`3oool20000o`040?ooo`000?l0003o0?ooo`80003o00<0oooo0000
o`000?l01`000?l00`3oool0003o0000o`030?ooo`050?l0003oool0o`000?l0003oool01@3o0000
0`3oool0o`000?l000080?l000040?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0k0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`000?l00`3oool0
0`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o00001`3oool0
0`3o0000oooo0?l000040?ooo`030?l0003oool0oooo04@0oooo00<0003o0?ooo`3oool04@3oool2
0000o`80oooo00<0003o0?ooo`000?l01P000?l40?ooo`L0003o00<0oooo0000o`000?l00`3oool0
0`3o0000oooo0?l000020?l000030?ooo`3o0000o`0000<0o`0000H0oooo0?l0003o0000oooo0?l0
003oool40?l000040?ooo`3o0000oooo0?l00080oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0j0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool06`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo
0?ooo`0Q0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0o`0000@0oooo00<0o`000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0C0?ooo`05
0000o`3oool0oooo0000o`3oool01P000?l0103oool0003o0?ooo`3oool60000o`050?ooo`000?l0
003o0?ooo`000?l00`3oool00`3o0000oooo0?l000020?l000030?ooo`3o0000o`0000<0o`0000D0
oooo0?l0003oool0o`000?ooo`030?l000050?ooo`3o0000o`000?ooo`3o00000P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo03/0oooo0@0000010?ooo`008P3oool00`000000oooo
0?ooo`0L0?ooo`80003o0`3oool010000?l0oooo0000o`000?l60?ooo`030000o`3oool0003o00@0
oooo00<0003o0?ooo`3oool08@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0o`000?oo
o`3oool00`3oool0103o0000oooo0?ooo`3o00030?ooo`030?l0003oool0oooo04<0oooo00<0003o
0?ooo`3oool02P3oool50000o`D0oooo00D0003o0?ooo`3oool0003o0?ooo`060000o`040?ooo`00
0?l0003o0?ooo`D0003o00D0oooo0000o`000?l0oooo0000o`030?ooo`030?l0003oool0o`000080
o`0000<0oooo0?l0003o0000103o00020?ooo`D0o`0000D0oooo0?l0003o0000oooo0?l000020?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0?03oool100000040oooo000500000080
oooo100000050?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool07@3oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`<0oooo0P000?l00`3oool0003o0?ooo`040?oo
o`030000o`3oool0oooo0280oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0
oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo04<0oooo00<0
003o0?ooo`3oool0203oool20000o`D0oooo0P000?l40?ooo`030000o`3oool0oooo00<0003o00<0
oooo0000o`000?l01P000?l00`3oool0003o0000o`020000o`040?ooo`000?l0oooo0000o`<0oooo
00D0o`000?ooo`3o0000o`000?ooo`040?l000030?ooo`3o0000o`0000H0o`0000D0oooo0?l0003o
0000oooo0?l000020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0?@3oool10000
0040oooo00020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000040?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N
0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l30?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0903oool01@3o0000oooo0?ooo`3oool0o`000080
oooo0`3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000A`3oool00`000?l0oooo0?ooo`050?oo
o`80003o2@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0003o0?ooo`80003o00@0oooo
0000o`000?l0oooo20000?l0103oool0003o0?ooo`000?l40?ooo`040?l0003oool0o`000?ooo`80
o`0000D0oooo0?l0003o0000o`000?ooo`070?l000040?ooo`3o0000o`000?l00080oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0m0?ooo`4000000@3oool00080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`050000o`3oool0oooo0?ooo`000?l00P3o
ool20000o`<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003o
ool0oooo0080o`001P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo04H0oooo00@0
003o0?ooo`3oool0oooo0`000?l<0?ooo`80003o0`3oool010000?l0oooo0000o`3oool=0000o`04
0?ooo`000?l0oooo0000o`@0oooo00H0o`000?ooo`3o0000oooo0?l0003oool>0?l000040?ooo`3o
0000oooo0?l000<0oooo0`3o00100?ooo`4000000@3oool00080oooo00<000000?ooo`3oool00`3o
ool5000000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`<00000
803oool20000o`80oooo0P000?l30?ooo`80003o1@3oool00`000?l0oooo0?ooo`0W0?ooo`040?l0
003oool0oooo0?ooo`80o`000P3oool20?l000@0oooo00<0o`000?ooo`3oool0B03oool30000oa40
oooo00X0003o0?ooo`3oool0oooo0000o`3oool0003o0?ooo`000?l0oooo10000?l00`3oool0003o
0?ooo`020000o`040?ooo`000?l0oooo0000o`D0oooo00L0o`000?ooo`3oool0o`000?ooo`3o0000
oooo00X0o`0000H0oooo0?l0003oool0o`000?ooo`3o00030?ooo`030?l0003oool0oooo0440oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo0?ooo`<0003o1P3oool20000obX0
oooo00<0o`000?ooo`3oool00P3oool20?l000D0oooo00<0o`000?ooo`3oool0GP3oool20000o`80
oooo00<0003o0?ooo`000?l00`000?l00`3oool0003o0000o`040000o`040?ooo`000?l0oooo0000
o`L0oooo00L0o`000?ooo`3oool0o`000?ooo`3o0000oooo00H0o`0000<0oooo0?l0003oool01@3o
00030?ooo`030?l0003oool0oooo0480oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo0640oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`030000o`80oooo
0P000?l20?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0o`000P3oool20?l00080
oooo1`3o00020?ooo`050?l0003oool0oooo0?ooo`3o0000A@3oool100000040oooo0003000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool0HP3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool2
0000o`040?ooo`000?l0oooo0000o`T0oooo00<0o`000?ooo`3o00000P3oool0103o0000oooo0?l0
003o00030?ooo`030?l0003oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l000160?ooo`40
00000@3oool00080oooo00<000000?ooo`3oool00`3oool4000000@0oooo1@0000030?ooo`@00000
1P3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
;@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo06<0oooo00D0003o0?ooo`3oool0
oooo0000o`020?ooo`@0003o0P3oool010000?l0oooo0?ooo`000?l90?ooo`040?l0003oool0oooo
0?l00080oooo00<0o`000?ooo`3oool00`3o00020?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3oool0A@3oool100000040oooo000R0?ooo`030000003oool0oooo02D0oooo00<0003o0?oo
o`3oool00`3oool20000oc40oooo0P3o00030?ooo`80o`00I`3oool01@000?l0oooo0?ooo`3oool0
003o00D0oooo0P000?l20?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo0P3o
00000`3oool0o`000?l000030?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?oo
o`160?ooo`4000000@3oool00280oooo00<000000?ooo`3oool09P3oool20000o`030?ooo`000?l0
003o03D0oooo0`3o001Z0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01@000?l0oooo0?oo
o`3oool0003o00`0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`<0o`000P3oool01@3o0000
oooo0?ooo`3oool0o`0004T0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo0:80oooo00<0003o0?ooo`3oool00P3oool40000o`<0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`170?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0
cP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
B03oool100000040oooo000R0?ooo`030000003oool0oooo0<l0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0o`00
103oool00`3o0000oooo0?ooo`190?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0d03o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3o
ool20?l000@0oooo00<0o`000?ooo`3oool0BP3oool100000040oooo000R0?ooo`030000003oool0
oooo0=00oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0BP3oool100000040oooo000R0?ooo`030000003oool0oooo
0=40oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool0BP3oool100000040oooo000R0?ooo`030000003oool0oooo0=80
oooo10000?lD0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0B`3oool100000040
oooo000R0?ooo`030000003oool0oooo0>X0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`1<0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0j`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo04d0oooo0@0000010?ooo`008P3oool00`000000oooo0?ooo`3/
0?ooo`050?l0003oool0oooo0?ooo`3o0000D03oool100000040oooo000R0?ooo`030000003oool0
oooo0>d0oooo00@0o`000?ooo`3oool0o`00D03oool100000040oooo000R0?ooo`030000003oool0
oooo0>h0oooo0P3o001A0?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3o
oom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3o
oom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3o
oom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3o
oom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3o
oom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`400000
0@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<00000
0?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?oo
o`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo
00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3o
oom20?ooo`4000000@3oool00280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool0
0280oooo00<000000?ooo`3oool0o`3ooom20?ooo`4000000@3oool00280oooo00<000000?ooo`3o
ool0o`3ooom20?ooo`4000000@3oool00280ooooo`00001600000040oooo003o0?ooofT0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-12.2143, -8.6075, 0.484942, \
0.484942}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 971}},
WindowSize->{1272, 937},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 106, 3, 128, "Section"],

Cell[CellGroupData[{
Cell[1836, 57, 75, 0, 67, "Subsubtitle"],
Cell[1914, 59, 314, 5, 61, "Text"],
Cell[2231, 66, 315, 6, 119, "Input"],
Cell[2549, 74, 200, 4, 39, "Text"],
Cell[2752, 80, 334, 6, 98, "Input"],
Cell[3089, 88, 40, 0, 39, "Text"],
Cell[3132, 90, 238, 5, 119, "Input"],
Cell[3373, 97, 183, 4, 39, "Text"],
Cell[3559, 103, 6424, 116, 1484, "Input"],
Cell[9986, 221, 37, 0, 39, "Text"],

Cell[CellGroupData[{
Cell[10048, 225, 438, 7, 77, "Input"],
Cell[10489, 234, 40466, 1264, 370, 14086, 934, "GraphicsData", "PostScript", \
"Graphics"],
Cell[50958, 1500, 137, 3, 35, "Output"],
Cell[51098, 1505, 47551, 1687, 370, 19283, 1333, "GraphicsData", \
"PostScript", "Graphics"],
Cell[98652, 3194, 137, 3, 35, "Output"]
}, Open  ]],
Cell[98804, 3200, 145, 3, 39, "Text"],
Cell[98952, 3205, 513, 9, 161, "Input"],
Cell[99468, 3216, 47, 0, 39, "Text"],

Cell[CellGroupData[{
Cell[99540, 3220, 1441, 29, 161, "Input"],
Cell[100984, 3251, 81813, 2671, 370, 31071, 2040, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

